@@ -1,39 +1,26 @@
 /*
-    Copyright (c) 2015 Daniel Vrátil <dvratil@kde.org>
+    SPDX-FileCopyrightText: 2015 Daniel Vrátil <dvratil@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KMANAGESIEVE_SESSIONTHREAD_P_H
-#define KMANAGESIEVE_SESSIONTHREAD_P_H
+#pragma once
 
 #include <QObject>
 #include <QUrl>
 #include <memory>
 
 #include <KIO/Global>
-#include <QSslSocket>
 #include <KSslErrorUiData>
+#include <QSslSocket>
 
-#include "sasl-common.h"
 #include "response.h"
+#include "sasl-common.h"
 
 class QTimer;
 
-namespace KManageSieve {
+namespace KManageSieve
+{
 class Session;
 
 class SessionThread : public QObject
@@ -42,7 +29,7 @@ class SessionThread : public QObject
 
 public:
     explicit SessionThread(Session *session, QObject *parent = nullptr);
-    ~SessionThread();
+    ~SessionThread() override;
 
     void connectToHost(const QUrl &url);
     void disconnectFromHost(bool sendLogout);
@@ -97,10 +84,9 @@ private:
 
     QByteArray m_data;
     Response m_lastResponse;
-    qint64 m_pendingQuantity;
+    qint64 m_pendingQuantity = -1;
 
     QTimer *m_sslCheck = nullptr;
 };
 } // namespace KManageSieve
 
-#endif // KMANAGESIEVE_SESSIONTHREAD_P_H
