@@ -1,30 +1,17 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "autocreatescriptutil_p.h"
 
 #include <KLocalizedString>
 
-#include <KPluginLoader>
 #include <KPluginFactory>
-#include <QStringList>
+#include <KPluginMetaData>
 #include <QRegularExpression>
+#include <QStringList>
 
 #include "autocreatescripts/sieveconditions/widgets/regexpeditorlineedit.h"
 
@@ -51,8 +38,7 @@ QString AutoCreateScriptUtil::createList(const QString &str, QChar separator, bo
         return QString();
     case 1:
         return QLatin1String("\"") + list.first() + QLatin1String("\"");
-    default:
-    {
+    default: {
         const QString result = createList(list, addEndSemiColon);
         return result;
     }
@@ -108,7 +94,7 @@ QStringList AutoCreateScriptUtil::createListFromString(QString str)
     lst = str.split(QStringLiteral(", "));
     QStringList resultLst;
     resultLst.reserve(lst.count());
-    for (QString s : qAsConst(lst)) {
+    for (QString s : std::as_const(lst)) {
         s.remove(QLatin1Char('"'));
         resultLst << s.trimmed();
     }
@@ -155,7 +141,7 @@ QString AutoCreateScriptUtil::strValue(QXmlStreamReader &element)
 QString AutoCreateScriptUtil::listValueToStr(QXmlStreamReader &element)
 {
     const QStringList lst = AutoCreateScriptUtil::listValue(element);
-    //Don't add semicolon
+    // Don't add semicolon
     return createList(lst, false);
 }
 
@@ -175,9 +161,10 @@ QStringList AutoCreateScriptUtil::listValue(QXmlStreamReader &element)
 
 QString AutoCreateScriptUtil::fixListValue(QString valueStr)
 {
+    static QRegularExpression reg(QStringLiteral("^\\[\\s*\".*\"\\s*]$"));
     if (!(valueStr.startsWith(QLatin1Char('[')) && valueStr.endsWith(QLatin1Char(']')))) {
         valueStr = QStringLiteral("\"%1\"").arg(valueStr);
-    } else if (valueStr.contains(QRegularExpression(QStringLiteral("^\\[\\s*\".*\"\\s*]$")))) {
+    } else if (valueStr.contains(reg)) {
     } else {
         valueStr = QStringLiteral("\"%1\"").arg(valueStr);
     }
@@ -207,10 +194,11 @@ QString AutoCreateScriptUtil::indentation()
 KSieveUi::AbstractMoveImapFolderWidget *AutoCreateScriptUtil::createImapFolderWidget()
 {
     KSieveUi::AbstractMoveImapFolderWidget *edit = nullptr;
-    KPluginLoader loader(QStringLiteral("libksieve/imapfoldercompletionplugin"));
-    KPluginFactory *factory = loader.factory();
-    if (factory) {
-        edit = factory->create<KSieveUi::AbstractMoveImapFolderWidget>();
+    const KPluginMetaData editWidgetPlugin(QStringLiteral("libksieve/imapfoldercompletionplugin"));
+
+    const auto result = KPluginFactory::instantiatePlugin<KSieveUi::AbstractMoveImapFolderWidget>(editWidgetPlugin);
+    if (result) {
+        edit = result.plugin;
     } else {
         edit = new KSieveUi::MoveImapFolderWidget;
     }
@@ -220,10 +208,11 @@ KSieveUi::AbstractMoveImapFolderWidget *AutoCreateScriptUtil::createImapFolderWi
 KSieveUi::AbstractSelectEmailLineEdit *AutoCreateScriptUtil::createSelectEmailsWidget()
 {
     KSieveUi::AbstractSelectEmailLineEdit *edit = nullptr;
-    KPluginLoader loader(QStringLiteral("libksieve/emaillineeditplugin"));
-    KPluginFactory *factory = loader.factory();
-    if (factory) {
-        edit = factory->create<KSieveUi::AbstractSelectEmailLineEdit>();
+    const KPluginMetaData editWidgetPlugin(QStringLiteral("libksieve/emaillineeditplugin"));
+
+    const auto result = KPluginFactory::instantiatePlugin<KSieveUi::AbstractSelectEmailLineEdit>(editWidgetPlugin);
+    if (result) {
+        edit = result.plugin;
     } else {
         edit = new AddressLineEdit;
     }
@@ -233,10 +222,11 @@ KSieveUi::AbstractSelectEmailLineEdit *AutoCreateScriptUtil::createSelectEmailsW
 AbstractRegexpEditorLineEdit *AutoCreateScriptUtil::createRegexpEditorLineEdit(QWidget *parent)
 {
     KSieveUi::AbstractRegexpEditorLineEdit *edit = nullptr;
-    KPluginLoader loader(QStringLiteral("libksieve/regexpeditorlineeditplugin"));
-    KPluginFactory *factory = loader.factory();
-    if (factory) {
-        edit = factory->create<KSieveUi::AbstractRegexpEditorLineEdit>(parent);
+    const KPluginMetaData editWidgetPlugin(QStringLiteral("libksieve/regexpeditorlineeditplugin"));
+
+    const auto result = KPluginFactory::instantiatePlugin<KSieveUi::AbstractRegexpEditorLineEdit>(editWidgetPlugin, parent);
+    if (result) {
+        edit = result.plugin;
     } else {
         edit = new KSieveUi::RegexpEditorLineEdit(parent);
     }
@@ -247,9 +237,13 @@ QString AutoCreateScriptUtil::generateConditionComment(const QString &comment)
 {
     QString strComment;
     if (!comment.trimmed().isEmpty()) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        const QVector<QStringView> commentList = QStringView(comment).split(QLatin1Char('\n'));
+        for (const QStringView str : commentList) {
+#else
         const QVector<QStringRef> commentList = comment.splitRef(QLatin1Char('\n'));
-
         for (const QStringRef &str : commentList) {
+#endif
             if (str.isEmpty()) {
                 strComment += QLatin1Char('\n');
             } else {
