@@ -1,34 +1,22 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AUTOCREATESCRIPTUTIL_H
-#define AUTOCREATESCRIPTUTIL_H
+#pragma once
 
+#include "ksieveui_private_export.h"
+#include <KSieveUi/AbstractRegexpEditorLineEdit>
 #include <QString>
 #include <QStringList>
 #include <QXmlStreamReader>
-#include <KSieveUi/AbstractRegexpEditorLineEdit>
-#include "ksieveui_private_export.h"
-namespace KSieveUi {
+namespace KSieveUi
+{
 class AbstractMoveImapFolderWidget;
 class AbstractSelectEmailLineEdit;
-namespace AutoCreateScriptUtil {
+namespace AutoCreateScriptUtil
+{
 Q_REQUIRED_RESULT QString createMultiLine(const QString &str);
 Q_REQUIRED_RESULT QString createList(const QString &str, QChar separator, bool addEndSemiColon = true);
 Q_REQUIRED_RESULT QString createList(const QStringList &lst, bool addSemiColon = true, bool protectSlash = false);
@@ -53,4 +41,3 @@ KSIEVEUI_TESTS_EXPORT KSieveUi::AbstractMoveImapFolderWidget *createImapFolderWi
 KSIEVEUI_TESTS_EXPORT KSieveUi::AbstractSelectEmailLineEdit *createSelectEmailsWidget();
 }
 }
-#endif // AUTOCREATESCRIPTUTIL_H
