@@ -1,27 +1,14 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "selectheadertypecomboboxtest.h"
 #include "../sieveconditions/widgets/selectheadertypecombobox.h"
 
-#include <QTest>
 #include <QLineEdit>
+#include <QTest>
 
 #ifndef Q_OS_WIN
 void initLocale()
@@ -51,7 +38,7 @@ void SelectHeaderTypeComboBoxTest::shouldHaveDefaultValue()
     QCOMPARE(combox.currentIndex(), 0);
     QVERIFY(!combox.itemText(combox.count() - 1).isEmpty());
     QCOMPARE(combox.itemData(combox.count() - 1).toString(), QString());
-    //Don't verify first element and last as we already did
+    // Don't verify first element and last as we already did
     for (int i = 1; i < combox.count() - 1; ++i) {
         QVERIFY(!combox.itemData(i).toString().isEmpty());
         QVERIFY(!combox.itemText(i).isEmpty());
@@ -66,7 +53,7 @@ void SelectHeaderTypeComboBoxTest::shouldHaveDefaultValue()
     QVERIFY(!combox1.itemText(combox1.count() - 1).isEmpty());
     QCOMPARE(combox1.itemData(combox1.count() - 1).toString(), QString());
 
-    //Don't verify first element and last as we already did
+    // Don't verify first element and last as we already did
     for (int i = 1; i < combox1.count() - 1; ++i) {
         QVERIFY(!combox1.itemData(i).toString().isEmpty());
         QVERIFY(!combox1.itemText(i).isEmpty());
