@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVEPREVIEWGENERATEDCODEWIDGETTEST_H
-#define SIEVEPREVIEWGENERATEDCODEWIDGETTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,9 +13,8 @@ class SievePreviewGeneratedCodeWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit SievePreviewGeneratedCodeWidgetTest(QObject *parent = nullptr);
-    ~SievePreviewGeneratedCodeWidgetTest() = default;
+    ~SievePreviewGeneratedCodeWidgetTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
 };
 
-#endif // SIEVEPREVIEWGENERATEDCODEWIDGETTEST_H
