@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "selectmimetypecombobox.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
@@ -27,7 +14,7 @@ SelectMimeTypeComboBox::SelectMimeTypeComboBox(QWidget *parent)
     : QComboBox(parent)
 {
     initialize();
-    connect(this, QOverload<int>::of(&SelectMimeTypeComboBox::activated), this, &SelectMimeTypeComboBox::valueChanged);
+    connect(this, &SelectMimeTypeComboBox::activated, this, &SelectMimeTypeComboBox::valueChanged);
 }
 
 SelectMimeTypeComboBox::~SelectMimeTypeComboBox()
@@ -36,7 +23,7 @@ SelectMimeTypeComboBox::~SelectMimeTypeComboBox()
 
 void SelectMimeTypeComboBox::initialize()
 {
-    //TODO verify
+    // TODO verify
     addItem(i18n("JPEG"), QStringLiteral("image/jpeg"));
     addItem(i18n("TIFF"), QStringLiteral("image/tiff"));
     addItem(i18n("PNG"), QStringLiteral("image/png"));
