@@ -1,32 +1,20 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionextracttext.h"
 #include "editor/sieveeditorutil.h"
 
 #include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QLineEdit>
 
+#include "libksieve_debug.h"
+#include <QGridLayout>
 #include <QLabel>
 #include <QSpinBox>
 #include <QXmlStreamReader>
-#include "libksieve_debug.h"
-#include <QGridLayout>
 
 using namespace KSieveUi;
 SieveActionExtractText::SieveActionExtractText(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
@@ -36,25 +24,26 @@ SieveActionExtractText::SieveActionExtractText(SieveEditorGraphicalModeWidget *s
 
 QWidget *SieveActionExtractText::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    QGridLayout *grid = new QGridLayout;
-    grid->setContentsMargins(0, 0, 0, 0);
+    auto w = new QWidget(parent);
+    auto grid = new QGridLayout;
+    grid->setContentsMargins({});
     w->setLayout(grid);
 
-    QLabel *lab = new QLabel(i18n("Number of characters:"));
+    auto lab = new QLabel(i18n("Number of characters:"));
     grid->addWidget(lab, 0, 0);
 
-    QSpinBox *nbCharacters = new QSpinBox;
+    auto nbCharacters = new QSpinBox;
     nbCharacters->setMinimum(1);
     nbCharacters->setMaximum(99999);
     nbCharacters->setObjectName(QStringLiteral("numberOfCharacters"));
     grid->addWidget(nbCharacters, 0, 1);
-    connect(nbCharacters, QOverload<int>::of(&QSpinBox::valueChanged), this, &SieveActionExtractText::valueChanged);
+    connect(nbCharacters, &QSpinBox::valueChanged, this, &SieveActionExtractText::valueChanged);
 
     lab = new QLabel(i18n("Stored in variable name:"));
     grid->addWidget(lab, 1, 0);
 
-    QLineEdit *variableName = new QLineEdit;
+    auto variableName = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(variableName, w);
     connect(variableName, &QLineEdit::textChanged, this, &SieveActionExtractText::valueChanged);
     variableName->setObjectName(QStringLiteral("variablename"));
     grid->addWidget(variableName, 1, 1);
@@ -69,19 +58,19 @@ void SieveActionExtractText::setParamWidgetValue(QXmlStreamReader &element, QWid
 
         if (tagName == QLatin1String("tag")) {
             element.skipCurrentElement();
-            //TODO ?
+            // TODO ?
         } else if (tagName == QLatin1String("num")) {
-            QSpinBox *numberOfCharacters = w->findChild<QSpinBox *>(QStringLiteral("numberOfCharacters"));
+            auto numberOfCharacters = w->findChild<QSpinBox *>(QStringLiteral("numberOfCharacters"));
             numberOfCharacters->setValue(element.readElementText().toInt());
         } else if (tagName == QLatin1String("str")) {
-            QLineEdit *variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
+            auto variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
             variableName->setText(element.readElementText());
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             element.skipCurrentElement();
-            //implement in the future ?
+            // implement in the future ?
         } else {
             unknownTag(tagName, error);
             qCDebug(LIBKSIEVE_LOG) << " SieveActionExtractText::setParamWidgetValue unknown tagName " << tagName;
