@@ -1,32 +1,19 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionkeep.h"
-#include "editor/sieveeditorutil.h"
-#include "widgets/selectflagswidget.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
+#include "editor/sieveeditorutil.h"
+#include "widgets/selectflagswidget.h"
 
-#include <KLocalizedString>
-#include <QLabel>
-#include <QHBoxLayout>
-#include <QXmlStreamReader>
 #include "libksieve_debug.h"
+#include <KLocalizedString>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 SieveActionKeep::SieveActionKeep(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
@@ -54,20 +41,21 @@ QString SieveActionKeep::code(QWidget *w) const
 QString SieveActionKeep::help() const
 {
     return i18n(
-        "The \"keep\" action is whatever action is taken in lieu of all other actions, if no filtering happens at all; generally, this simply means to file the message into the user's main mailbox.");
+        "The \"keep\" action is whatever action is taken in lieu of all other actions, if no filtering happens at all; generally, this simply means to file "
+        "the message into the user's main mailbox.");
 }
 
 QWidget *SieveActionKeep::createParamWidget(QWidget *parent) const
 {
     if (mHasFlagSupport) {
-        QWidget *w = new QWidget(parent);
-        QHBoxLayout *lay = new QHBoxLayout;
-        lay->setContentsMargins(0, 0, 0, 0);
+        auto w = new QWidget(parent);
+        auto lay = new QHBoxLayout;
+        lay->setContentsMargins({});
         w->setLayout(lay);
-        QLabel *addFlags = new QLabel(i18n("Add flags:"));
+        auto addFlags = new QLabel(i18n("Add flags:"));
         lay->addWidget(addFlags);
 
-        SelectFlagsWidget *flagsWidget = new SelectFlagsWidget;
+        auto flagsWidget = new SelectFlagsWidget;
         connect(flagsWidget, &SelectFlagsWidget::valueChanged, this, &SieveActionKeep::valueChanged);
         flagsWidget->setObjectName(QStringLiteral("flagswidget"));
         lay->addWidget(flagsWidget);
@@ -77,26 +65,26 @@ QWidget *SieveActionKeep::createParamWidget(QWidget *parent) const
     }
 }
 
-bool SieveActionKeep::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
+void SieveActionKeep::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     if (mHasFlagSupport) {
         while (element.readNextStartElement()) {
             const QStringRef tagName = element.name();
             if (tagName == QLatin1String("list")) {
-                SelectFlagsWidget *flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
+                auto flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
                 flagsWidget->setFlags(AutoCreateScriptUtil::listValue(element));
             } else if (tagName == QLatin1String("str")) {
-                SelectFlagsWidget *flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
+                auto flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
                 flagsWidget->setFlags(QStringList() << element.readElementText());
             } else if (tagName == QLatin1String("tag") && element.readElementText() == QLatin1String("flags")) {
-                //nothing :)
-                //Don't skip here.
+                // nothing :)
+                // Don't skip here.
             } else if (tagName == QLatin1String("crlf")) {
                 element.skipCurrentElement();
-                //nothing
+                // nothing
             } else if (tagName == QLatin1String("comment")) {
                 element.skipCurrentElement();
-                //implement in the future ?
+                // implement in the future ?
             } else {
                 unknownTag(tagName, error);
                 qCDebug(LIBKSIEVE_LOG) << " SieveActionAbstractFlags::setParamWidgetValue unknown tag :" << tagName;
@@ -105,8 +93,6 @@ bool SieveActionKeep::setParamWidgetValue(QXmlStreamReader &element, QWidget *w,
     } else {
         qCDebug(LIBKSIEVE_LOG) << " Server doesn't support imapflags";
     }
-
-    return true;
 }
 
 QStringList SieveActionKeep::needRequires(QWidget *) const
