@@ -1,33 +1,20 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionredirect.h"
-#include "editor/sieveeditorutil.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
+#include "editor/sieveeditorutil.h"
 #include "widgets/addresslineedit.h"
 
 #include <KLocalizedString>
 
-#include <QHBoxLayout>
-#include <QCheckBox>
-#include <QXmlStreamReader>
 #include "libksieve_debug.h"
+#include <QCheckBox>
+#include <QHBoxLayout>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 
@@ -40,18 +27,18 @@ SieveActionRedirect::SieveActionRedirect(SieveEditorGraphicalModeWidget *sieveGr
 
 QWidget *SieveActionRedirect::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
     if (mHasCopySupport) {
-        QCheckBox *copy = new QCheckBox(i18n("Keep a copy"));
+        auto copy = new QCheckBox(i18n("Keep a copy"));
         copy->setObjectName(QStringLiteral("copy"));
         connect(copy, &QCheckBox::clicked, this, &SieveActionRedirect::valueChanged);
         lay->addWidget(copy);
     }
     if (mHasListSupport) {
-        QCheckBox *list = new QCheckBox(i18n("Use list"));
+        auto list = new QCheckBox(i18n("Use list"));
         list->setObjectName(QStringLiteral("list"));
         connect(list, &QCheckBox::clicked, this, &SieveActionRedirect::valueChanged);
         lay->addWidget(list);
@@ -69,21 +56,21 @@ void SieveActionRedirect::setParamWidgetValue(QXmlStreamReader &element, QWidget
     while (element.readNextStartElement()) {
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("str")) {
-            AbstractSelectEmailLineEdit *edit = w->findChild<AbstractSelectEmailLineEdit *>(QStringLiteral("RedirectEdit"));
+            auto edit = w->findChild<AbstractSelectEmailLineEdit *>(QStringLiteral("RedirectEdit"));
             const QString tagValue = element.readElementText();
             edit->setText(AutoCreateScriptUtil::quoteStr(tagValue));
         } else if (tagName == QLatin1String("tag")) {
             const QString tagValue = element.readElementText();
             if (tagValue == QLatin1String("copy")) {
                 if (mHasCopySupport) {
-                    QCheckBox *copy = w->findChild<QCheckBox *>(QStringLiteral("copy"));
+                    auto copy = w->findChild<QCheckBox *>(QStringLiteral("copy"));
                     copy->setChecked(true);
                 } else {
                     serverDoesNotSupportFeatures(QStringLiteral("copy"), error);
                 }
             } else if (tagValue == QLatin1String("list")) {
                 if (mHasListSupport) {
-                    QCheckBox *list = w->findChild<QCheckBox *>(QStringLiteral("list"));
+                    auto list = w->findChild<QCheckBox *>(QStringLiteral("list"));
                     list->setChecked(true);
                 } else {
                     serverDoesNotSupportFeatures(QStringLiteral("list"), error);
@@ -94,10 +81,10 @@ void SieveActionRedirect::setParamWidgetValue(QXmlStreamReader &element, QWidget
             }
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             setComment(element.readElementText());
-            //implement in the future ?
+            // implement in the future ?
         } else {
             unknownTag(tagName, error);
             qCDebug(LIBKSIEVE_LOG) << " SieveActionRedirect::setParamWidgetValue unknown tagName " << tagName;
@@ -149,12 +136,14 @@ QStringList SieveActionRedirect::needRequires(QWidget *parent) const
 QString SieveActionRedirect::help() const
 {
     QString helpStr = i18n(
-        "The \"redirect\" action is used to send the message to another user at a supplied address, as a mail forwarding feature does.  The \"redirect\" action makes no changes to the message body or existing headers, but it may add new headers.");
+        "The \"redirect\" action is used to send the message to another user at a supplied address, as a mail forwarding feature does.  The \"redirect\" "
+        "action makes no changes to the message body or existing headers, but it may add new headers.");
     if (mHasCopySupport) {
-        helpStr += QLatin1Char('\n') + i18n(
-            "If the optional \":copy\" keyword is specified, the tagged command does not cancel the implicit \"keep\". Instead, it redirects a copy in addition to whatever else is happening to the message.");
+        helpStr += QLatin1Char('\n')
+            + i18n("If the optional \":copy\" keyword is specified, the tagged command does not cancel the implicit \"keep\". Instead, it redirects a copy in "
+                   "addition to whatever else is happening to the message.");
     }
-    //TODO add list info
+    // TODO add list info
     return helpStr;
 }
 
