@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SIEVEACTIONREDIRECT_H
-#define SIEVEACTIONREDIRECT_H
+#pragma once
 
 #include "sieveaction.h"
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveActionRedirect : public SieveAction
 {
     Q_OBJECT
@@ -21,10 +21,10 @@ public:
     Q_REQUIRED_RESULT QString help() const override;
 
     Q_REQUIRED_RESULT QUrl href() const override;
+
 private:
     bool mHasCopySupport = false;
     bool mHasListSupport = false;
 };
 }
 
-#endif // SIEVEACTIONREDIRECT_H
