@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SIEVEACTIONVACATION_H
-#define SIEVEACTIONVACATION_H
+#pragma once
 
 #include "sieveaction.h"
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveActionVacation : public SieveAction
 {
     Q_OBJECT
@@ -22,9 +22,9 @@ public:
     Q_REQUIRED_RESULT QStringList needRequires(QWidget *parent) const override;
     Q_REQUIRED_RESULT QString help() const override;
     Q_REQUIRED_RESULT QUrl href() const override;
+
 private:
     bool mHasVacationSecondsSupport = false;
 };
 }
 
-#endif // SIEVEACTIONVACATION_H
