@@ -1,34 +1,24 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "addresslineedit.h"
-#include <KLocalizedString>
 #include <KColorScheme>
+#include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QHBoxLayout>
+#include <QLineEdit>
 
 using namespace KSieveUi;
 
 AddressLineEdit::AddressLineEdit(QWidget *parent)
     : AbstractSelectEmailLineEdit(parent)
+    , mLineEdit(new QLineEdit(this))
 {
-    QHBoxLayout *mainLayout = new QHBoxLayout(this);
-    mainLayout->setContentsMargins(0, 0, 0, 0);
-    mLineEdit = new QLineEdit(this);
+    auto mainLayout = new QHBoxLayout(this);
+    mainLayout->setContentsMargins({});
+    new KPIM::LineEditCatchReturnKey(mLineEdit, this);
     mainLayout->addWidget(mLineEdit);
     mLineEdit->setClearButtonEnabled(true);
     mLineEdit->setPlaceholderText(i18n("Define Email Address..."));
@@ -52,10 +42,10 @@ void AddressLineEdit::verifyAddress()
     QString styleSheet;
     const QString lineEditText = text();
     mEmailIsInvalid = !lineEditText.contains(QLatin1Char('@'));
-    //Fix check multi address
+    // Fix check multi address
     if (mNegativeBackground.isEmpty()) {
         KStatefulBrush bgBrush = KStatefulBrush(KColorScheme::View, KColorScheme::NegativeText);
-        mNegativeBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(this).color().name());
+        mNegativeBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(palette()).color().name());
     }
     if (mEmailIsInvalid) {
         styleSheet = mNegativeBackground;
