@@ -1,40 +1,28 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sieveactionwidgetlister.h"
 #include "autocreatescriptdialog.h"
-#include "sieveeditorgraphicalmodewidget.h"
-#include "sievescriptdescriptiondialog.h"
+#include "autocreatescriptutil_p.h"
+#include "commonwidgets/sievehelpbutton.h"
 #include "sieveactions/sieveaction.h"
 #include "sieveactions/sieveactionlist.h"
-#include "commonwidgets/sievehelpbutton.h"
-#include "autocreatescriptutil_p.h"
+#include "sieveeditorgraphicalmodewidget.h"
+#include "sievescriptdescriptiondialog.h"
 
-#include <QPushButton>
 #include <KLocalizedString>
 #include <QIcon>
+#include <QPushButton>
+#include <QUrl>
 
+#include "libksieve_debug.h"
 #include <QComboBox>
 #include <QGridLayout>
 #include <QLabel>
 #include <QPointer>
-#include "libksieve_debug.h"
 #include <QToolButton>
 #include <QWhatsThis>
 
@@ -97,8 +85,13 @@ void SieveActionWidget::generatedScript(QString &script, QStringList &required,
             indent += AutoCreateScriptUtil::indentation();
         }
         if (!comment.trimmed().isEmpty()) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            const QVector<QStringView> commentList = QStringView(comment).split(QLatin1Char('\n'));
+            for (const QStringView str : commentList) {
+#else
             const QVector<QStringRef> commentList = comment.splitRef(QLatin1Char('\n'));
             for (const QStringRef &str : commentList) {
+#endif
                 if (str.isEmpty()) {
                     script += QLatin1Char('\n');
                 } else {
@@ -113,37 +106,34 @@ void SieveActionWidget::generatedScript(QString &script, QStringList &required,
 void SieveActionWidget::initWidget()
 {
     mLayout = new QGridLayout(this);
-    mLayout->setContentsMargins(0, 0, 0, 0);
+    mLayout->setContentsMargins({});
 
     mComboBox = new QComboBox;
     mComboBox->setEditable(false);
     mComboBox->setMinimumWidth(50);
     const QVector<KSieveUi::SieveAction *> list = KSieveUi::SieveActionList::actionList(mSieveGraphicalModeWidget);
-    QVector<KSieveUi::SieveAction *>::const_iterator it;
-    QVector<KSieveUi::SieveAction *>::const_iterator end(list.constEnd());
-    int index = 0;
     QStringList listCapabilities = mSieveGraphicalModeWidget->sieveCapabilities();
-    //imapflags was old name of imap4flags but still used.
+    // imapflags was old name of imap4flags but still used.
     if (listCapabilities.contains(QLatin1String("imap4flags"))) {
         listCapabilities.append(QStringLiteral("imapflags"));
     }
-    for (index = 0, it = list.constBegin(); it != end; ++it, ++index) {
-        if ((*it)->needCheckIfServerHasCapability()) {
-            if (listCapabilities.contains((*it)->serverNeedsCapability())) {
+    for (const auto &action : list) {
+        if (action->needCheckIfServerHasCapability()) {
+            if (listCapabilities.contains(action->serverNeedsCapability())) {
                 // append to the list of actions:
-                mActionList.append(*it);
-                connect(*it, &SieveAction::valueChanged, this, &SieveActionWidget::valueChanged);
+                mActionList.append(action);
+                connect(action, &SieveAction::valueChanged, this, &SieveActionWidget::valueChanged);
                 // add (i18n-ized) name to combo box
-                mComboBox->addItem((*it)->label(), (*it)->name());
+                mComboBox->addItem(action->label(), action->name());
             } else {
-                delete(*it);
+                delete (action);
             }
         } else {
             // append to the list of actions:
-            mActionList.append(*it);
-            connect(*it, &SieveAction::valueChanged, this, &SieveActionWidget::valueChanged);
+            mActionList.append(action);
+            connect(action, &SieveAction::valueChanged, this, &SieveActionWidget::valueChanged);
             // add (i18n-ized) name to combo box
-            mComboBox->addItem((*it)->label(), (*it)->name());
+            mComboBox->addItem(action->label(), action->name());
         }
     }
 
@@ -167,7 +157,7 @@ void SieveActionWidget::initWidget()
 
     updateGeometry();
 
-    connect(mComboBox, QOverload<int>::of(&QComboBox::activated), this, &SieveActionWidget::slotActionChanged);
+    connect(mComboBox, &QComboBox::activated, this, &SieveActionWidget::slotActionChanged);
 
     mAdd = new QPushButton(this);
     mAdd->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
@@ -231,7 +221,7 @@ void SieveActionWidget::slotActionChanged(int index)
         mHelpButton->setEnabled(!action->help().isEmpty());
         mCommentButton->setEnabled(true);
         setFilterAction(action->createParamWidget(this));
-        //All actions after stop will not execute => don't allow to add more actions.
+        // All actions after stop will not execute => don't allow to add more actions.
         const bool enableAddAction = (action->name() != QLatin1String("stop"));
         mAdd->setEnabled(enableAddAction);
     } else {
@@ -267,32 +257,30 @@ void SieveActionWidget::setLocaleVariable(const SieveGlobalVariableActionWidget:
     if (index != -1) {
         mComboBox->setCurrentIndex(index);
         slotActionChanged(index);
-        KSieveUi::SieveActionSetVariable *localVar = dynamic_cast<KSieveUi::SieveActionSetVariable *>(mActionList.at(index));
+        auto localVar = qobject_cast<KSieveUi::SieveActionSetVariable *>(mActionList.at(index));
         if (localVar) {
             localVar->setLocalVariable(this, var);
         }
     } else {
-        //error += i18n("Script contains unsupported feature \"%1\"", actionName) + QLatin1Char('\n');
-        //qCDebug(LIBKSIEVE_LOG) << "Action " << actionName << " not supported";
+        // error += i18n("Script contains unsupported feature \"%1\"", actionName) + QLatin1Char('\n');
+        // qCDebug(LIBKSIEVE_LOG) << "Action " << actionName << " not supported";
     }
 }
 
-bool SieveActionWidget::setAction(const QString &actionName, QXmlStreamReader &element, const QString &comment, QString &error)
+void SieveActionWidget::setAction(const QString &actionName, QXmlStreamReader &element, const QString &comment, QString &error)
 {
     const int index = mComboBox->findData(actionName);
-    bool result = false;
     if (index != -1) {
         mComboBox->setCurrentIndex(index);
         slotActionChanged(index);
         KSieveUi::SieveAction *action = mActionList.at(index);
-        result = action->setParamWidgetValue(element, this, error);
+        action->setParamWidgetValue(element, this, error);
         action->setComment(comment);
     } else {
         error += i18n("Script contains unsupported feature \"%1\"", actionName) + QLatin1Char('\n');
         qCDebug(LIBKSIEVE_LOG) << "Action " << actionName << " not supported";
         element.skipCurrentElement();
     }
-    return result;
 }
 
 SieveActionWidgetLister::SieveActionWidgetLister(SieveEditorGraphicalModeWidget *graphicalModeWidget, QWidget *parent)
@@ -338,7 +326,7 @@ void SieveActionWidgetLister::updateAddRemoveButton()
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
     for (; wIt != wEnd; ++wIt) {
-        SieveActionWidget *w = qobject_cast<SieveActionWidget *>(*wIt);
+        auto w = qobject_cast<SieveActionWidget *>(*wIt);
         w->updateAddRemoveButton(addButtonEnabled, removeButtonEnabled);
     }
 }
@@ -349,7 +337,7 @@ void SieveActionWidgetLister::generatedScript(QString &script, QStringList &requ
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
     for (; wIt != wEnd; ++wIt) {
-        SieveActionWidget *w = qobject_cast<SieveActionWidget *>(*wIt);
+        auto w = qobject_cast<SieveActionWidget *>(*wIt);
         w->generatedScript(script, requireModules, onlyActions, inForEveryPartLoop);
     }
 }
@@ -364,7 +352,7 @@ void SieveActionWidgetLister::reconnectWidget(SieveActionWidget *w)
 void SieveActionWidgetLister::clearWidget(QWidget *aWidget)
 {
     if (aWidget) {
-        SieveActionWidget *widget = static_cast<SieveActionWidget *>(aWidget);
+        auto widget = static_cast<SieveActionWidget *>(aWidget);
         widget->clear();
     }
     Q_EMIT valueChanged();
@@ -372,7 +360,7 @@ void SieveActionWidgetLister::clearWidget(QWidget *aWidget)
 
 QWidget *SieveActionWidgetLister::createWidget(QWidget *parent)
 {
-    SieveActionWidget *w = new SieveActionWidget(mSieveGraphicalModeWidget, parent);
+    auto w = new SieveActionWidget(mSieveGraphicalModeWidget, parent);
     reconnectWidget(w);
     return w;
 }
@@ -384,7 +372,7 @@ int SieveActionWidgetLister::actionNumber() const
 
 void SieveActionWidgetLister::loadLocalVariable(const SieveGlobalVariableActionWidget::VariableElement &var)
 {
-    SieveActionWidget *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
+    auto w = qobject_cast<SieveActionWidget *>(widgets().constLast());
     if (w->isConfigurated()) {
         addWidgetAfterThisWidget(widgets().constLast());
         w = qobject_cast<SieveActionWidget *>(widgets().constLast());
@@ -400,16 +388,16 @@ void SieveActionWidgetLister::loadScript(QXmlStreamReader &element, bool onlyAct
         if (tagName == QLatin1String("action")) {
             if (element.attributes().hasAttribute(QLatin1String("name"))) {
                 const QString actionName = element.attributes().value(QLatin1String("name")).toString();
-                SieveActionWidget *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
+                auto w = qobject_cast<SieveActionWidget *>(widgets().constLast());
                 if (w->isConfigurated()) {
                     addWidgetAfterThisWidget(widgets().constLast());
                     w = qobject_cast<SieveActionWidget *>(widgets().constLast());
                 }
                 w->setAction(actionName, element, comment, error);
-                //comment.clear();
+                // comment.clear();
             } else if (tagName == QLatin1String("crlf")) {
                 element.skipCurrentElement();
-                //nothing
+                // nothing
             } else {
                 qCDebug(LIBKSIEVE_LOG) << " SieveActionWidgetLister::loadScript don't have name attribute " << tagName;
             }
@@ -433,7 +421,7 @@ void SieveActionWidgetLister::loadScript(QXmlStreamReader &element, bool onlyAct
                     } else {
                         addWidgetAfterThisWidget(widgets().constLast());
                     }
-                    SieveActionWidget *w = qobject_cast<SieveActionWidget *>(widgets().constLast());
+                    auto w = qobject_cast<SieveActionWidget *>(widgets().constLast());
                     w->setAction(actionName, element, comment, error);
                     comment.clear();
                 } else {
@@ -447,7 +435,7 @@ void SieveActionWidgetLister::loadScript(QXmlStreamReader &element, bool onlyAct
                 previousActionWasAComment = true;
                 comment += element.readElementText();
             } else if (tagName == QLatin1String("crlf")) {
-                //Add new line if previous action was a comment
+                // Add new line if previous action was a comment
                 if (previousActionWasAComment) {
                     comment += QLatin1Char('\n');
                 }
