@@ -1,46 +1,33 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionlist.h"
 #include "sievecondition.h"
-#include "sieveconditionheader.h"
 #include "sieveconditionaddress.h"
-#include "sieveconditionsize.h"
 #include "sieveconditionenvelope.h"
 #include "sieveconditionexists.h"
-#include "sieveconditiontrue.h"
 #include "sieveconditionfalse.h"
-//RFC5173 (extension)
+#include "sieveconditionheader.h"
+#include "sieveconditionsize.h"
+#include "sieveconditiontrue.h"
+// RFC5173 (extension)
 #include "sieveconditionbody.h"
-//rfc5260
-#include "sieveconditiondate.h"
+// rfc5260
 #include "sieveconditioncurrentdate.h"
+#include "sieveconditiondate.h"
 
 #include "sieveconditionmailboxexists.h"
 
+#include "sieveconditionenvironment.h"
+#include "sieveconditionihave.h"
 #include "sieveconditionspamtest.h"
 #include "sieveconditionvirustest.h"
-#include "sieveconditionihave.h"
-#include "sieveconditionenvironment.h"
 
+#include "sieveconditionconvert.h"
 #include "sieveconditionhasflag.h"
 #include "sieveconditionmetadata.h"
-#include "sieveconditionconvert.h"
 #include "sieveconditionmetadataexists.h"
 #include "sieveconditionservermetadata.h"
 #include "sieveconditionservermetadataexists.h"
