@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,12 +11,13 @@
 #include <KLocalizedString>
 #include <QLineEdit>
 
-#include <QWidget>
-#include <QLabel>
-#include <QHBoxLayout>
 #include "libksieve_debug.h"
-#include <QXmlStreamReader>
 #include <KSieveUi/AbstractMoveImapFolderWidget>
+#include <Libkdepim/LineEditCatchReturnKey>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QWidget>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 SieveConditionMetaData::SieveConditionMetaData(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
@@ -26,21 +27,21 @@ SieveConditionMetaData::SieveConditionMetaData(SieveEditorGraphicalModeWidget *s
 
 QWidget *SieveConditionMetaData::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *lay = new QHBoxLayout;
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
     lay->setContentsMargins({});
     w->setLayout(lay);
 
-    auto *selectType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
+    auto selectType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     selectType->setObjectName(QStringLiteral("selecttype"));
     connect(selectType, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionMetaData::valueChanged);
     lay->addWidget(selectType);
 
-    auto *grid = new QGridLayout;
+    auto grid = new QGridLayout;
     grid->setContentsMargins({});
     lay->addLayout(grid);
 
-    QLabel *lab = new QLabel(i18n("Mailbox:"));
+    auto lab = new QLabel(i18n("Mailbox:"));
     grid->addWidget(lab, 0, 0);
 
     KSieveUi::AbstractMoveImapFolderWidget *mailbox = AutoCreateScriptUtil::createImapFolderWidget();
@@ -53,7 +54,8 @@ QWidget *SieveConditionMetaData::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Annotations:"));
     grid->addWidget(lab, 1, 0);
 
-    auto *annotation = new QLineEdit;
+    auto annotation = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(annotation, w);
     connect(annotation, &QLineEdit::textChanged, this, &SieveConditionMetaData::valueChanged);
     annotation->setObjectName(QStringLiteral("annotation"));
     grid->addWidget(annotation, 1, 1);
@@ -114,7 +116,8 @@ QString SieveConditionMetaData::serverNeedsCapability() const
 QString SieveConditionMetaData::help() const
 {
     return i18n(
-        "This test retrieves the value of the mailbox annotation \"annotation-name\" for the mailbox \"mailbox\". The retrieved value is compared to the \"key-list\". The test returns true if the annotation exists and its value matches any of the keys.");
+        "This test retrieves the value of the mailbox annotation \"annotation-name\" for the mailbox \"mailbox\". The retrieved value is compared to the "
+        "\"key-list\". The test returns true if the annotation exists and its value matches any of the keys.");
 }
 
 void SieveConditionMetaData::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
@@ -126,21 +129,18 @@ void SieveConditionMetaData::setParamWidgetValue(QXmlStreamReader &element, QWid
         if (tagName == QLatin1String("str")) {
             const QString tagValue = element.readElementText();
             switch (index) {
-            case 0:
-            {
-                auto *mailbox = w->findChild<KSieveUi::AbstractMoveImapFolderWidget *>(QStringLiteral("mailbox"));
+            case 0: {
+                auto mailbox = w->findChild<KSieveUi::AbstractMoveImapFolderWidget *>(QStringLiteral("mailbox"));
                 mailbox->setText(tagValue);
                 break;
             }
-            case 1:
-            {
-                auto *annotation = w->findChild<QLineEdit *>(QStringLiteral("annotation"));
+            case 1: {
+                auto annotation = w->findChild<QLineEdit *>(QStringLiteral("annotation"));
                 annotation->setText(AutoCreateScriptUtil::quoteStr(tagValue));
                 break;
             }
-            case 2:
-            {
-                auto *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+            case 2: {
+                auto value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
                 value->setCode(AutoCreateScriptUtil::quoteStr(tagValue));
                 break;
             }
@@ -151,11 +151,11 @@ void SieveConditionMetaData::setParamWidgetValue(QXmlStreamReader &element, QWid
             }
             ++index;
         } else if (tagName == QLatin1String("tag")) {
-            auto *selectType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("selecttype"));
+            auto selectType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("selecttype"));
             selectType->setCode(AutoCreateScriptUtil::tagValueWithCondition(element.readElementText(), notCondition), name(), error);
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
         } else {
