@@ -1,33 +1,20 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionvirustest.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
 #include "editor/sieveeditorutil.h"
-#include "widgets/selectrelationalmatchtype.h"
 #include "widgets/selectcomparatorcombobox.h"
+#include "widgets/selectrelationalmatchtype.h"
 
 #include <KLocalizedString>
 
-#include <QSpinBox>
 #include "libksieve_debug.h"
-#include <QXmlStreamReader>
+#include <QSpinBox>
 #include <QVBoxLayout>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 
@@ -38,26 +25,26 @@ SieveConditionVirusTest::SieveConditionVirusTest(SieveEditorGraphicalModeWidget
 
 QWidget *SieveConditionVirusTest::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    QVBoxLayout *lay = new QVBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto w = new QWidget(parent);
+    auto lay = new QVBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
 
-    SelectRelationalMatchType *relation = new SelectRelationalMatchType;
+    auto relation = new SelectRelationalMatchType;
     connect(relation, &SelectRelationalMatchType::valueChanged, this, &SieveConditionVirusTest::valueChanged);
     relation->setObjectName(QStringLiteral("relation"));
     lay->addWidget(relation);
 
-    SelectComparatorComboBox *comparator = new SelectComparatorComboBox(mSieveGraphicalModeWidget);
+    auto comparator = new SelectComparatorComboBox(mSieveGraphicalModeWidget);
     connect(comparator, &SelectComparatorComboBox::valueChanged, this, &SieveConditionVirusTest::valueChanged);
     comparator->setObjectName(QStringLiteral("comparator"));
     lay->addWidget(comparator);
 
-    QSpinBox *spinbox = new QSpinBox;
+    auto spinbox = new QSpinBox;
     spinbox->setMaximum(5);
     spinbox->setMinimum(0);
     spinbox->setObjectName(QStringLiteral("value"));
-    connect(spinbox, QOverload<int>::of(&QSpinBox::valueChanged), this, &SieveConditionVirusTest::valueChanged);
+    connect(spinbox, &QSpinBox::valueChanged, this, &SieveConditionVirusTest::valueChanged);
     lay->addWidget(spinbox);
     return w;
 }
@@ -114,14 +101,14 @@ void SieveConditionVirusTest::setParamWidgetValue(QXmlStreamReader &element, QWi
             if (tagValue == QLatin1String("count") || tagValue == QLatin1String("value")) {
                 if (element.readNextStartElement()) {
                     if (element.name() == QLatin1String("str")) {
-                        SelectRelationalMatchType *relation = w->findChild<SelectRelationalMatchType *>(QStringLiteral("relation"));
+                        auto relation = w->findChild<SelectRelationalMatchType *>(QStringLiteral("relation"));
                         relation->setCode(AutoCreateScriptUtil::tagValue(tagValue), element.readElementText(), name(), error);
                     }
                 }
             } else if (tagValue == QLatin1String("comparator")) {
                 if (element.readNextStartElement()) {
                     if (element.name() == QLatin1String("str")) {
-                        SelectComparatorComboBox *comparator = w->findChild<SelectComparatorComboBox *>(QStringLiteral("comparator"));
+                        auto comparator = w->findChild<SelectComparatorComboBox *>(QStringLiteral("comparator"));
                         comparator->setCode(element.readElementText(), name(), error);
                     }
                 }
@@ -130,11 +117,11 @@ void SieveConditionVirusTest::setParamWidgetValue(QXmlStreamReader &element, QWi
                 qCDebug(LIBKSIEVE_LOG) << " SieveConditionVirusTest::setParamWidgetValue unknown tagValue " << tagValue;
             }
         } else if (tagName == QLatin1String("str")) {
-            QSpinBox *spinbox = w->findChild<QSpinBox *>(QStringLiteral("value"));
+            auto spinbox = w->findChild<QSpinBox *>(QStringLiteral("value"));
             spinbox->setValue(element.readElementText().toInt());
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
         } else {
