@@ -1,34 +1,23 @@
 /*
-   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "regexpeditorlineedit.h"
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QHBoxLayout>
 #include <QLineEdit>
 
 using namespace KSieveUi;
 RegexpEditorLineEdit::RegexpEditorLineEdit(QWidget *parent)
     : KSieveUi::AbstractRegexpEditorLineEdit(parent)
+    , mLineEdit(new QLineEdit(this))
 {
-    QHBoxLayout *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    mainLayout->setContentsMargins(0, 0, 0, 0);
-    mLineEdit = new QLineEdit(this);
+    mainLayout->setContentsMargins({});
+    new KPIM::LineEditCatchReturnKey(mLineEdit, this);
     mLineEdit->setObjectName(QStringLiteral("lineedit"));
     connect(mLineEdit, &QLineEdit::textChanged, this, &RegexpEditorLineEdit::textChanged);
     mainLayout->addWidget(mLineEdit);
@@ -40,8 +29,8 @@ RegexpEditorLineEdit::~RegexpEditorLineEdit()
 
 void RegexpEditorLineEdit::switchToRegexpEditorLineEdit(bool regexpEditor)
 {
-    Q_UNUSED(regexpEditor);
-    //Nothing here
+    Q_UNUSED(regexpEditor)
+    // Nothing here
 }
 
 void KSieveUi::RegexpEditorLineEdit::setCode(const QString &str)
