@@ -1,35 +1,22 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "selectdatewidget.h"
 #include "sievedatespinbox.h"
 
+#include <KDateComboBox>
 #include <KLocalizedString>
+#include <KTimeComboBox>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QComboBox>
 #include <QLineEdit>
-#include <KDateComboBox>
-#include <KTimeComboBox>
 
+#include "libksieve_debug.h"
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QStackedWidget>
-#include <QSpinBox>
-#include "libksieve_debug.h"
 #include <QTime>
 
 using namespace KSieveUi;
@@ -45,11 +32,11 @@ SelectDateWidget::~SelectDateWidget()
 
 void SelectDateWidget::initialize()
 {
-    QHBoxLayout *lay = new QHBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto lay = new QHBoxLayout(this);
+    lay->setContentsMargins({});
 
-    mDateType = new QComboBox;
-    connect(mDateType, QOverload<int>::of(&QComboBox::activated), this, &SelectDateWidget::slotDateTypeActivated);
+    mDateType = new QComboBox(this);
+    connect(mDateType, &QComboBox::activated, this, &SelectDateWidget::slotDateTypeActivated);
     mDateType->addItem(i18n("Year"), QVariant::fromValue(KSieveUi::SelectDateWidget::Year));
     mDateType->addItem(i18n("Month"), QVariant::fromValue(KSieveUi::SelectDateWidget::Month));
     mDateType->addItem(i18n("Day"), QVariant::fromValue(KSieveUi::SelectDateWidget::Day));
@@ -65,25 +52,26 @@ void SelectDateWidget::initialize()
     mDateType->addItem(i18n("Weekday"), QVariant::fromValue(KSieveUi::SelectDateWidget::Weekday));
     lay->addWidget(mDateType);
 
-    QLabel *lab = new QLabel(i18n("value:"));
+    auto lab = new QLabel(i18n("value:"), this);
     lay->addWidget(lab);
 
     mStackWidget = new QStackedWidget;
     lay->addWidget(mStackWidget);
 
-    mDateLineEdit = new QLineEdit;
+    mDateLineEdit = new QLineEdit(this);
+    new KPIM::LineEditCatchReturnKey(mDateLineEdit, this);
     mStackWidget->addWidget(mDateLineEdit);
     connect(mDateLineEdit, &QLineEdit::textChanged, this, &SelectDateWidget::valueChanged);
 
-    mDateValue = new SieveDateSpinBox;
+    mDateValue = new SieveDateSpinBox(this);
     mStackWidget->addWidget(mDateValue);
-    connect(mDateValue, QOverload<int>::of(&QSpinBox::valueChanged), this, &SelectDateWidget::valueChanged);
+    connect(mDateValue, &QSpinBox::valueChanged, this, &SelectDateWidget::valueChanged);
 
-    mDateEdit = new KDateComboBox;
+    mDateEdit = new KDateComboBox(this);
     mStackWidget->addWidget(mDateEdit);
     connect(mDateEdit, &KDateComboBox::dateChanged, this, &SelectDateWidget::valueChanged);
 
-    mTimeEdit = new KTimeComboBox;
+    mTimeEdit = new KTimeComboBox(this);
     mStackWidget->addWidget(mTimeEdit);
     connect(mTimeEdit, &KTimeComboBox::timeChanged, this, &SelectDateWidget::valueChanged);
 
@@ -92,7 +80,7 @@ void SelectDateWidget::initialize()
 
 void SelectDateWidget::slotDateTypeActivated(int index)
 {
-    const DateType type = mDateType->itemData(index).value<KSieveUi::SelectDateWidget::DateType>();
+    const auto type = mDateType->itemData(index).value<KSieveUi::SelectDateWidget::DateType>();
     switch (type) {
     case Year:
     case Month:
@@ -143,7 +131,7 @@ QString SelectDateWidget::dateValue(SelectDateWidget::DateType type) const
         str = QLocale::c().toString(mDateEdit->date());
         break;
     case Julian:
-        //TODO
+        // TODO
         str = QLocale::c().toString(mDateEdit->date());
         break;
     case Time:
@@ -245,7 +233,7 @@ QString SelectDateWidget::dateType(SelectDateWidget::DateType type) const
 
 QString SelectDateWidget::code() const
 {
-    const DateType type = mDateType->itemData(mDateType->currentIndex()).value<KSieveUi::SelectDateWidget::DateType>();
+    const auto type = mDateType->itemData(mDateType->currentIndex()).value<KSieveUi::SelectDateWidget::DateType>();
     return QStringLiteral("\"%1\" \"%2\"").arg(dateType(type), dateValue(type));
 }
 
@@ -257,7 +245,7 @@ void SelectDateWidget::setCode(const QString &type, const QString &value)
     } else {
         mDateType->setCurrentIndex(0);
     }
-    const DateType dateType = mDateType->itemData(index).value<KSieveUi::SelectDateWidget::DateType>();
+    const auto dateType = mDateType->itemData(index).value<KSieveUi::SelectDateWidget::DateType>();
     switch (dateType) {
     case Month:
     case Day:
