@@ -1,52 +1,38 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sievescriptblockwidget.h"
+#include "autocreatescriptutil_p.h"
 #include "sieveactionwidgetlister.h"
 #include "sieveconditionwidgetlister.h"
-#include "autocreatescriptutil_p.h"
 
 #include <KLocalizedString>
-#include <KComboBox>
-#include <QPushButton>
+#include <QComboBox>
 #include <QIcon>
+#include <QPushButton>
 
-#include <QXmlStreamReader>
-#include <QVBoxLayout>
-#include <QGroupBox>
-#include <QButtonGroup>
-#include <QRadioButton>
-#include <QLabel>
 #include "libksieve_debug.h"
+#include <QButtonGroup>
+#include <QGroupBox>
+#include <QLabel>
+#include <QRadioButton>
+#include <QVBoxLayout>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 
 SieveScriptBlockWidget::SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *graphicalModeWidget, QWidget *parent)
     : SieveWidgetPageAbstract(parent)
-    , mMatchCondition(AndCondition)
     , mSieveGraphicalModeWidget(graphicalModeWidget)
 {
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
-    topLayout->setContentsMargins(0, 0, 0, 0);
+    auto topLayout = new QVBoxLayout(this);
+    topLayout->setContentsMargins({});
 
-    mConditions = new QGroupBox(i18n("Conditions"));
-    QVBoxLayout *vbox = new QVBoxLayout;
+    mConditions = new QGroupBox(i18n("Conditions"), this);
+    auto vbox = new QVBoxLayout;
 
     mAllMessageRBtn = new QRadioButton(i18n("Match all messages"), this);
     mMatchAll = new QRadioButton(i18n("Match a&ll of the following"), this);
@@ -59,12 +45,12 @@ SieveScriptBlockWidget::SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *g
     mMatchAny->setChecked(false);
     mAllMessageRBtn->setChecked(false);
 
-    QButtonGroup *bg = new QButtonGroup(this);
+    auto bg = new QButtonGroup(this);
     bg->addButton(mMatchAll);
     bg->addButton(mMatchAny);
     bg->addButton(mAllMessageRBtn);
 
-    connect(bg, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, &SieveScriptBlockWidget::slotRadioClicked);
+    connect(bg, &QButtonGroup::buttonClicked, this, &SieveScriptBlockWidget::slotRadioClicked);
     mConditions->setLayout(vbox);
 
     mScriptConditionLister = new SieveConditionWidgetLister(mSieveGraphicalModeWidget, this);
@@ -73,7 +59,7 @@ SieveScriptBlockWidget::SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *g
 
     topLayout->addWidget(mConditions, 0, Qt::AlignTop);
 
-    QGroupBox *actions = new QGroupBox(i18n("Actions"));
+    auto actions = new QGroupBox(i18n("Actions"), this);
     vbox = new QVBoxLayout;
     actions->setLayout(vbox);
     mScriptActionLister = new SieveActionWidgetLister(mSieveGraphicalModeWidget, this);
@@ -81,15 +67,15 @@ SieveScriptBlockWidget::SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *g
     vbox->addWidget(mScriptActionLister, 0, Qt::AlignTop);
     topLayout->addWidget(actions);
 
-    QHBoxLayout *newBlockLayout = new QHBoxLayout;
-    QLabel *lab = new QLabel(i18n("Add new block:"));
+    auto newBlockLayout = new QHBoxLayout;
+    auto lab = new QLabel(i18n("Add new block:"));
     newBlockLayout->addWidget(lab);
-    mNewBlockType = new KComboBox;
+    mNewBlockType = new QComboBox(this);
     newBlockLayout->addWidget(mNewBlockType);
     mNewBlockType->addItem(i18n("\"elsif\" block"));
     mNewBlockType->addItem(i18n("\"else\" block"));
 
-    mAddBlockType = new QPushButton;
+    mAddBlockType = new QPushButton(this);
     mAddBlockType->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     mAddBlockType->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
     newBlockLayout->addWidget(mAddBlockType);
@@ -181,7 +167,7 @@ void SieveScriptBlockWidget::generatedScript(QString &script, QStringList &requi
     bool onlyActions = false;
     if (mMatchCondition == AllCondition) {
         onlyActions = true;
-        //Just actions type
+        // Just actions type
     } else if (pageType() == BlockElse) {
         script += QLatin1String("else {\n");
     } else {
@@ -201,7 +187,7 @@ void SieveScriptBlockWidget::generatedScript(QString &script, QStringList &requi
         case BlockElse:
             break;
         default:
-            //We can got here.
+            // We can got here.
             break;
         }
 
