@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "sievetextedittest.h"
@@ -40,12 +29,12 @@ void SieveTextEditTest::comment_data()
     QTest::addColumn<QString>("result");
     QTest::addColumn<int>("startcursorposition");
     QTest::addColumn<int>("endcursorposition");
-    QTest::newRow("onelinewithoutselection") <<  QStringLiteral("foo") << QStringLiteral("#foo") << -1 << -1;
-    //Comment first line
-    QTest::newRow("multilinewithoutselection") <<  QStringLiteral("foo\nbla") << QStringLiteral("#foo\nbla") << -1 << -1;
-    QTest::newRow("multilinewithoutselectionsecondline") <<  QStringLiteral("foo\nbla") << QStringLiteral("foo\n#bla") << 6 << 6;
-    QTest::newRow("onelinewithselection") <<  QStringLiteral("foo") << QStringLiteral("#foo") << 0 << 2;
-    QTest::newRow("multilinewithselection") <<  QStringLiteral("foo\nbla") << QStringLiteral("#foo\n#bla") << 0 << 5;
+    QTest::newRow("onelinewithoutselection") << QStringLiteral("foo") << QStringLiteral("#foo") << -1 << -1;
+    // Comment first line
+    QTest::newRow("multilinewithoutselection") << QStringLiteral("foo\nbla") << QStringLiteral("#foo\nbla") << -1 << -1;
+    QTest::newRow("multilinewithoutselectionsecondline") << QStringLiteral("foo\nbla") << QStringLiteral("foo\n#bla") << 6 << 6;
+    QTest::newRow("onelinewithselection") << QStringLiteral("foo") << QStringLiteral("#foo") << 0 << 2;
+    QTest::newRow("multilinewithselection") << QStringLiteral("foo\nbla") << QStringLiteral("#foo\n#bla") << 0 << 5;
 }
 
 void SieveTextEditTest::comment()
@@ -72,13 +61,13 @@ void SieveTextEditTest::uncomment_data()
     QTest::addColumn<QString>("result");
     QTest::addColumn<int>("startcursorposition");
     QTest::addColumn<int>("endcursorposition");
-    QTest::newRow("commentedline") <<  QStringLiteral("#foo") << QStringLiteral("foo") << -1 << -1;
-    QTest::newRow("nocommentedline") <<  QStringLiteral("foo") << QStringLiteral("foo") << -1 << -1;
-    QTest::newRow("onelinewithselection") <<  QStringLiteral("#foo") << QStringLiteral("foo") << 0 << 2;
-    //First line
-    QTest::newRow("multilinewithoutselection") <<  QStringLiteral("#foo\n#bla") << QStringLiteral("foo\n#bla") << -1 << -1;
-    QTest::newRow("multilinewithoutselectionsecondline") <<  QStringLiteral("#foo\n#bla") << QStringLiteral("#foo\nbla") << 6 << 6;
-    QTest::newRow("multilinewithselection") <<  QStringLiteral("#foo\n#bla") << QStringLiteral("foo\nbla") << 0 << 6;
+    QTest::newRow("commentedline") << QStringLiteral("#foo") << QStringLiteral("foo") << -1 << -1;
+    QTest::newRow("nocommentedline") << QStringLiteral("foo") << QStringLiteral("foo") << -1 << -1;
+    QTest::newRow("onelinewithselection") << QStringLiteral("#foo") << QStringLiteral("foo") << 0 << 2;
+    // First line
+    QTest::newRow("multilinewithoutselection") << QStringLiteral("#foo\n#bla") << QStringLiteral("foo\n#bla") << -1 << -1;
+    QTest::newRow("multilinewithoutselectionsecondline") << QStringLiteral("#foo\n#bla") << QStringLiteral("#foo\nbla") << 6 << 6;
+    QTest::newRow("multilinewithselection") << QStringLiteral("#foo\n#bla") << QStringLiteral("foo\nbla") << 0 << 6;
 }
 
 void SieveTextEditTest::uncomment()
