@@ -1,15 +1,15 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "sievetexteditwidgettest.h"
 #include "../sievetexteditwidget.h"
-#include <QTest>
-#include <editor/sievetextedit.h>
 #include <KPIMTextEdit/PlainTextEditFindBar>
 #include <KPIMTextEdit/SlideContainer>
+#include <QTest>
+#include <editor/sievetextedit.h>
 
 SieveTextEditWidgetTest::SieveTextEditWidgetTest(QObject *parent)
     : QObject(parent)
@@ -23,11 +23,11 @@ SieveTextEditWidgetTest::~SieveTextEditWidgetTest()
 void SieveTextEditWidgetTest::shouldHaveDefaultValue()
 {
     KSieveUi::SieveTextEditWidget w;
-    auto *textedit = w.findChild<KSieveUi::SieveTextEdit *>(QStringLiteral("textedit"));
+    auto textedit = w.findChild<KSieveUi::SieveTextEdit *>(QStringLiteral("textedit"));
     QVERIFY(textedit);
     QVERIFY(!textedit->isReadOnly());
 
-    auto *slider = w.findChild<KPIMTextEdit::SlideContainer *>(QStringLiteral("slidercontainer"));
+    auto slider = w.findChild<KPIMTextEdit::SlideContainer *>(QStringLiteral("slidercontainer"));
     QVERIFY(slider);
     QWidget *contentWidget = slider->content();
     QVERIFY(contentWidget);
