@@ -1,60 +1,47 @@
-/* Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "sieveeditortextmodewidget.h"
-#include "templates/sievetemplatewidget.h"
 #include "autocreatescripts/autocreatescriptdialog.h"
-#include "editor/sievetextedit.h"
-#include "editor/warningwidget/sieveeditorwarning.h"
-#include "editor/warningwidget/sieveeditorparsingmissingfeaturewarning.h"
 #include "editor/sieveeditortabwidget.h"
+#include "editor/sievetextedit.h"
+#include "editor/warningwidget/sieveeditorparsingmissingfeaturewarning.h"
+#include "editor/warningwidget/sieveeditorwarning.h"
 #include "sievescriptdebugger/sievescriptdebuggerdialog.h"
+#include "templates/sievetemplatewidget.h"
 
-#include "scriptsparsing/xmlprintingscriptbuilder.h"
 #include "scriptsparsing/parsingresultdialog.h"
+#include "scriptsparsing/xmlprintingscriptbuilder.h"
 
-#include <KPIMTextEdit/PlainTextEditFindBar>
-#include <KPIMTextEdit/PlainTextEditorWidget>
-#include <KPIMTextEdit/TextToSpeechWidget>
-#include <KPIMTextEdit/TextGotoLineWidget>
 #include "KSplitterCollapserButton"
 #include "webengine/sieveeditorhelphtmlwidget.h"
+#include <KPIMTextEdit/PlainTextEditFindBar>
+#include <KPIMTextEdit/PlainTextEditorWidget>
 #include <KPIMTextEdit/SlideContainer>
+#include <KPIMTextEdit/TextGotoLineWidget>
+#include <KPIMTextEdit/TextToSpeechWidget>
 
-#include <ksieve/parser.h>
 #include <ksieve/error.h>
+#include <ksieve/parser.h>
 #include <ksieve/scriptbuilder.h>
 
-#include <KLocalizedString>
-#include <KSharedConfig>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KMessageBox>
+#include <KSharedConfig>
 
-#include <QSplitter>
-#include <QShortcut>
-#include <QPointer>
-#include <QPushButton>
-#include <QVBoxLayout>
-#include <QPrinter>
-#include <QPrintDialog>
 #include <PimCommon/KPimPrintPreviewDialog>
+#include <QPointer>
+#include <QPrintDialog>
+#include <QPrinter>
+#include <QPushButton>
+#include <QShortcut>
+#include <QSplitter>
+#include <QVBoxLayout>
 
-#include <errno.h>
+#include <cerrno>
 #include <memory>
 
 using namespace KSieveUi;
@@ -62,8 +49,8 @@ using namespace KSieveUi;
 SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     : SieveEditorAbstractWidget(parent)
 {
-    QVBoxLayout *lay = new QVBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto lay = new QVBoxLayout(this);
+    lay->setContentsMargins({});
 
     mMainSplitter = new QSplitter;
     mMainSplitter->setOrientation(Qt::Vertical);
@@ -74,13 +61,13 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     //
     mSieveTemplateWidget = new SieveTemplateWidget(i18n("Sieve Template:"));
 
-    QWidget *textEditWidget = new QWidget;
-    QVBoxLayout *textEditLayout = new QVBoxLayout;
-    textEditLayout->setContentsMargins(0, 0, 0, 0);
+    auto textEditWidget = new QWidget;
+    auto textEditLayout = new QVBoxLayout;
+    textEditLayout->setContentsMargins({});
 
     mEditorWidget = new QWidget;
-    QVBoxLayout *editorWidgetLayout = new QVBoxLayout;
-    editorWidgetLayout->setContentsMargins(0, 0, 0, 0);
+    auto editorWidgetLayout = new QVBoxLayout;
+    editorWidgetLayout->setContentsMargins({});
     mEditorWidget->setLayout(editorWidgetLayout);
 
     mTabWidget = new SieveEditorTabWidget;
@@ -164,7 +151,7 @@ SieveEditorTextModeWidget::~SieveEditorTextModeWidget()
 
 void SieveEditorTextModeWidget::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "SieveEditor");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "SieveEditor");
     group.writeEntry("mainSplitter", mMainSplitter->sizes());
     group.writeEntry("templateSplitter", mTemplateSplitter->sizes());
 }
@@ -181,7 +168,7 @@ SieveEditorTabWidget *SieveEditorTextModeWidget::tabWidget() const
 
 void SieveEditorTextModeWidget::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "SieveEditor");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "SieveEditor");
     const QList<int> size = {400, 100};
 
     mMainSplitter->setSizes(group.readEntry("mainSplitter", size));
@@ -211,8 +198,7 @@ void SieveEditorTextModeWidget::slotShowGoToLine()
 void SieveEditorTextModeWidget::generateXml()
 {
     const QByteArray script = mTextEdit->toPlainText().toUtf8();
-    KSieve::Parser parser(script.begin(),
-                          script.begin() + script.length());
+    KSieve::Parser parser(script.begin(), script.begin() + script.length());
     KSieveUi::XMLPrintingScriptBuilder psb(2);
     parser.setScriptBuilder(&psb);
     const bool result = parser.parse();
@@ -229,8 +215,7 @@ void SieveEditorTextModeWidget::generateXml()
 void SieveEditorTextModeWidget::slotEditRule(const QString &selectedText)
 {
     const QByteArray script = selectedText.toUtf8();
-    KSieve::Parser parser(script.begin(),
-                          script.begin() + script.length());
+    KSieve::Parser parser(script.begin(), script.begin() + script.length());
     KSieveUi::XMLPrintingScriptBuilder psb(2);
     parser.setScriptBuilder(&psb);
     const bool result = parser.parse();
@@ -240,7 +225,7 @@ void SieveEditorTextModeWidget::slotEditRule(const QString &selectedText)
         dlg->setSieveImapAccountSettings(mSieveImapAccountSettings);
         dlg->setListOfIncludeFile(mListOfIncludeFile);
         QString error;
-        //qDebug() << " psb.result()" << psb.result();
+        // qDebug() << " psb.result()" << psb.result();
         dlg->loadScript(psb.result(), error);
         if (dlg->exec()) {
             QStringList requireModules;
@@ -268,7 +253,7 @@ QStringList SieveEditorTextModeWidget::insertNecessaryRequires(const QStringList
 {
     QStringList needToAddRequire;
     const QString plainText = mTextEdit->toPlainText();
-    for (const QString &module : qAsConst(requireModules)) {
+    for (const QString &module : std::as_const(requireModules)) {
         if (!plainText.contains(module)) {
             needToAddRequire.append(module);
         }
@@ -360,7 +345,7 @@ void SieveEditorTextModeWidget::copy()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->copy();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->copy();
     }
 }
@@ -370,7 +355,7 @@ void SieveEditorTextModeWidget::selectAll()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->selectAll();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->selectAll();
     }
 }
@@ -398,7 +383,7 @@ bool SieveEditorTextModeWidget::hasSelection() const
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         return mTextEdit->textCursor().hasSelection();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         return page->hasSelection();
     }
     return false;
@@ -409,7 +394,7 @@ void SieveEditorTextModeWidget::zoomIn()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->zoomIn();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->zoomIn();
     }
 }
@@ -419,7 +404,7 @@ void SieveEditorTextModeWidget::zoomOut()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->zoomOut();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->zoomOut();
     }
 }
@@ -472,7 +457,7 @@ void SieveEditorTextModeWidget::zoomReset()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->slotZoomReset();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->resetZoom();
     }
 }
@@ -488,7 +473,7 @@ void SieveEditorTextModeWidget::slotFind()
         mFindBar->showFind();
         mSliderContainer->slideIn();
         mFindBar->focusAndSetCursor();
-    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->find();
     }
 }
