@@ -1,64 +1,47 @@
 /*
-  Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "sieveeditorwidget.h"
 #include "sievepurposemenuwidget.h"
 
-#include "sieve-editor.h"
-#include "sieveeditortextmodewidget.h"
-#include "scriptsparsing/parsingutil.h"
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include "autocreatescripts/sievescriptparsingerrordialog.h"
+#include "editor/sieveinfodialog.h"
+#include "scriptsparsing/parsingutil.h"
+#include "sieve-editor.h"
 #include "sieveeditormenubar.h"
+#include "sieveeditortextmodewidget.h"
 
-#include <kns3/uploaddialog.h>
+#include <KActionMenu>
 #include <KLocalizedString>
-#include <KIconLoader>
-#include <QTemporaryDir>
-#include <kzip.h>
-#include <KIconEngine>
 #include <KStandardAction>
+#include <kzip.h>
 
 #include <PimCommon/PurposeMenuWidget>
 
-#include <QPushButton>
-#include <QVBoxLayout>
-#include <QStackedWidget>
-#include <QLabel>
-#include <QLineEdit>
-#include <QToolBar>
 #include "libksieve_debug.h"
 #include <QAction>
-#include <QPointer>
-#include <QDir>
-#include <QTemporaryFile>
+#include <QLabel>
+#include <QLineEdit>
+#include <QPushButton>
+#include <QStackedWidget>
+#include <QStandardPaths>
+#include <QToolBar>
+#include <QVBoxLayout>
 
 using namespace KSieveUi;
 
 SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     mDebug = !qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING");
 
-    QToolBar *toolbar = new QToolBar;
+    auto toolbar = new QToolBar;
     toolbar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
 
     mCheckSyntax = new QAction(i18n("Check Syntax"), this);
@@ -76,27 +59,24 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     connect(mSwitchMode, &QAction::triggered, this, &SieveEditorWidget::slotSwitchMode);
 
     if (mDebug) {
-        //Not necessary to translate it.
+        // Not necessary to translate it.
         mGenerateXml = new QAction(QStringLiteral("Generate xml"), this);
         connect(mGenerateXml, &QAction::triggered, this, &SieveEditorWidget::slotGenerateXml);
         toolbar->addAction(mGenerateXml);
     }
 
-    QStringList overlays;
-    overlays << QStringLiteral("list-add");
-    mShareScript = new QAction(QIcon(new KIconEngine(QStringLiteral("get-hot-new-stuff"), KIconLoader::global(), overlays)), i18n("Share Script..."), this);
-    connect(mShareScript, &QAction::triggered, this, &SieveEditorWidget::slotShareScript);
-    //Add action to toolBar
-
-    toolbar->addAction(mShareScript);
-
-    SievePurposeMenuWidget *purposeMenu = new SievePurposeMenuWidget(this, this);
-    QAction *shareAction = new QAction(i18n("Share..."), this);
+    auto purposeMenu = new SievePurposeMenuWidget(this, this);
+    auto shareAction = new KActionMenu(i18n("Share..."), this);
+    shareAction->setPopupMode(QToolButton::InstantPopup);
     shareAction->setMenu(purposeMenu->menu());
     shareAction->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
     purposeMenu->setEditorWidget(this);
     toolbar->addAction(shareAction);
 
+    mServerInfo = new QAction(i18n("Server Info"), this);
+    connect(mServerInfo, &QAction::triggered, this, &SieveEditorWidget::slotServerInfo);
+    toolbar->addAction(mServerInfo);
+
     SieveEditorMenuBar *menuBar = nullptr;
     if (useMenuBar) {
         menuBar = new SieveEditorMenuBar;
@@ -126,7 +106,6 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
         menuBar->fileMenu()->addSeparator();
         menuBar->fileMenu()->addAction(mSaveAs);
         menuBar->fileMenu()->addSeparator();
-        menuBar->fileMenu()->addAction(mShareScript);
         menuBar->toolsMenu()->addSeparator();
         menuBar->fileMenu()->addAction(shareAction);
         menuBar->toolsMenu()->addSeparator();
@@ -137,15 +116,15 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
 
     lay->addWidget(toolbar);
 
-    QHBoxLayout *nameLayout = new QHBoxLayout;
-    QLabel *label = new QLabel(i18n("Script name:"));
+    auto nameLayout = new QHBoxLayout;
+    auto label = new QLabel(i18n("Script name:"), this);
     nameLayout->addWidget(label);
-    mScriptName = new QLineEdit;
+    mScriptName = new QLineEdit(this);
     mScriptName->setReadOnly(true);
     nameLayout->addWidget(mScriptName);
     lay->addLayout(nameLayout);
 
-    lay->setContentsMargins(0, 0, 0, 0);
+    lay->setContentsMargins({});
     mStackedWidget = new QStackedWidget;
 
     mTextModeWidget = new SieveEditorTextModeWidget;
@@ -260,8 +239,7 @@ void SieveEditorWidget::updateOriginalScript()
 void SieveEditorWidget::print()
 {
     switch (mMode) {
-    case TextMode:
-    {
+    case TextMode: {
         bool wasModified = isModified();
         mTextModeWidget->print();
         setModified(wasModified);
@@ -278,8 +256,7 @@ void SieveEditorWidget::print()
 void SieveEditorWidget::printPreview()
 {
     switch (mMode) {
-    case TextMode:
-    {
+    case TextMode: {
         bool wasModified = isModified();
         mTextModeWidget->printPreview();
         setModified(wasModified);
@@ -386,37 +363,6 @@ void SieveEditorWidget::setModified(bool b)
     }
 }
 
-void SieveEditorWidget::slotShareScript()
-{
-    QTemporaryDir tmp;
-    QTemporaryFile tmpFile;
-    if (tmpFile.open()) {
-        QTextStream out(&tmpFile);
-        out.setCodec("UTF-8");
-        out << script();
-        tmpFile.close();
-        const QString sourceName = mScriptName->text();
-        const QString zipFileName = tmp.path() + QDir::separator() + sourceName + QLatin1String(".zip");
-        KZip *zip = new KZip(zipFileName);
-        if (zip->open(QIODevice::WriteOnly)) {
-            if (zip->addLocalFile(tmpFile.fileName(), sourceName + QLatin1String(".siv"))) {
-                zip->close();
-                QPointer<KNS3::UploadDialog> dialog = new KNS3::UploadDialog(QStringLiteral("ksieve_script.knsrc"), this);
-                dialog->setUploadFile(QUrl::fromLocalFile(zipFileName));
-                dialog->setUploadName(sourceName);
-                dialog->setDescription(i18nc("Default description for the source", "My Sieve Script"));
-                dialog->exec();
-                delete dialog;
-            } else {
-                zip->close();
-            }
-        }
-        delete zip;
-    } else {
-        qCWarning(LIBKSIEVE_LOG) << "Impossible to open temp file";
-    }
-}
-
 void SieveEditorWidget::changeMode(EditorMode mode)
 {
     if (mode != mMode) {
@@ -479,7 +425,7 @@ QString SieveEditorWidget::originalScript() const
 void SieveEditorWidget::setScript(const QString &script, bool clearUndoRedo)
 {
     mTextModeWidget->setScript(script, clearUndoRedo);
-    //Necessary to take text from editor otherwise script has \r\n
+    // Necessary to take text from editor otherwise script has \r\n
     mOriginalScript = mTextModeWidget->script();
 }
 
@@ -502,8 +448,7 @@ void SieveEditorWidget::addMessageEntry(const QString &errorMsg, const QColor &c
 {
     QString msg = errorMsg;
     msg.replace(QLatin1Char('\n'), QStringLiteral("<br>"));
-    const QString logText = QStringLiteral("<font color=%1>%2</font>")
-                            .arg(color.name(), msg);
+    const QString logText = QStringLiteral("<font color=%1>%2</font>").arg(color.name(), msg);
 
     setDebugScript(logText);
 }
@@ -629,8 +574,7 @@ void SieveEditorWidget::slotSwitchToGraphicalMode()
 void SieveEditorWidget::slotSwitchMode()
 {
     switch (mMode) {
-    case TextMode:
-    {
+    case TextMode: {
         bool result = false;
         const QString doc = ParsingUtil::parseScript(mTextModeWidget->currentscript(), result);
         if (result) {
@@ -649,8 +593,7 @@ void SieveEditorWidget::slotSwitchMode()
         }
         break;
     }
-    case GraphicMode:
-    {
+    case GraphicMode: {
         const QString script = mGraphicalModeWidget->currentscript();
         changeMode(TextMode);
         mTextModeWidget->setScript(script);
@@ -741,3 +684,10 @@ bool SieveEditorWidget::printSupportEnabled() const
     }
     return false;
 }
+
+void SieveEditorWidget::slotServerInfo()
+{
+    SieveInfoDialog dlg(this);
+    dlg.setServerInfo(mTextModeWidget->sieveCapabilities());
+    dlg.exec();
+}
