@@ -1,23 +1,12 @@
 /*
-  Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "sievetexteditwidget.h"
-#include <QVBoxLayout>
 #include "editor/sievetextedit.h"
+#include <QVBoxLayout>
 
 #include <KPIMTextEdit/PlainTextEditFindBar>
 #include <KPIMTextEdit/SlideContainer>
@@ -51,13 +40,12 @@ SieveTextEditWidget::SieveTextEditWidget(QWidget *parent)
 
 SieveTextEditWidget::~SieveTextEditWidget()
 {
-    delete d;
 }
 
 void SieveTextEditWidget::initialize(KSieveUi::SieveTextEdit *custom)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    auto mainLayout = new QVBoxLayout(this);
+    mainLayout->setContentsMargins({});
     if (custom) {
         d->mTextEdit = custom;
     } else {
