@@ -1,20 +1,22 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef SIEVETEXTEDITWIDGET_H
-#define SIEVETEXTEDITWIDGET_H
+#pragma once
 
-#include <QWidget>
 #include "ksieveui_private_export.h"
-namespace KPIMTextEdit {
+#include <QWidget>
+#include <memory>
+namespace KPIMTextEdit
+{
 class SlideContainer;
 class PlainTextEditFindBar;
 }
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveTextEdit;
 class SieveTextEditWidgetPrivate;
 class KSIEVEUI_TESTS_EXPORT SieveTextEditWidget : public QWidget
@@ -23,7 +25,7 @@ class KSIEVEUI_TESTS_EXPORT SieveTextEditWidget : public QWidget
 public:
     explicit SieveTextEditWidget(QWidget *parent = nullptr);
     SieveTextEditWidget(KSieveUi::SieveTextEdit *customTextEdit, QWidget *parent);
-    ~SieveTextEditWidget();
+    ~SieveTextEditWidget() override;
     void setReadOnly(bool readOnly);
 
     Q_REQUIRED_RESULT KSieveUi::SieveTextEdit *textEdit() const;
@@ -34,10 +36,9 @@ public Q_SLOTS:
 
 private:
     void initialize(KSieveUi::SieveTextEdit *custom = nullptr);
-    SieveTextEditWidgetPrivate *const d;
+    std::unique_ptr<SieveTextEditWidgetPrivate> const d;
     KSieveUi::SieveTextEdit *mTextEdit = nullptr;
     KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
     KPIMTextEdit::PlainTextEditFindBar *mFindBar = nullptr;
 };
 }
-#endif // SIEVETEXTEDITWIDGET_H
