@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveeditorparsingmissingfeaturewarning.h"
 #include "autocreatescripts/sievescriptparsingerrordialog.h"
@@ -22,7 +9,6 @@
 #include <KLocalizedString>
 #include <QAction>
 
-#include <QPointer>
 
 using namespace KSieveUi;
 
@@ -36,24 +22,22 @@ SieveEditorParsingMissingFeatureWarning::SieveEditorParsingMissingFeatureWarning
     connect(this, &SieveEditorParsingMissingFeatureWarning::linkActivated, this, &SieveEditorParsingMissingFeatureWarning::slotShowDetails);
 
     switch (type) {
-    case TextEditor:
-    {
-        QAction *action = new QAction(i18n("Switch in graphical mode"), this);
+    case TextEditor: {
+        auto action = new QAction(i18n("Switch to Graphical Mode"), this);
         connect(action, &QAction::triggered, this, &SieveEditorParsingMissingFeatureWarning::slotSwitchInGraphicalMode);
         addAction(action);
 
-        action = new QAction(i18n("Keep in text mode"), this);
+        action = new QAction(i18n("Stay in Text Mode"), this);
         connect(action, &QAction::triggered, this, &SieveEditorParsingMissingFeatureWarning::slotInActualMode);
         addAction(action);
         break;
     }
-    case GraphicEditor:
-    {
-        QAction *action = new QAction(i18n("Switch in text mode"), this);
+    case GraphicEditor: {
+        auto action = new QAction(i18n("Switch to Text Mode"), this);
         connect(action, &QAction::triggered, this, &SieveEditorParsingMissingFeatureWarning::slotSwitchInTextMode);
         addAction(action);
 
-        action = new QAction(i18n("Keep in Graphical mode"), this);
+        action = new QAction(i18n("Stay in Graphical Mode"), this);
         connect(action, &QAction::triggered, this, &SieveEditorParsingMissingFeatureWarning::slotInActualMode);
         addAction(action);
         break;
@@ -75,10 +59,9 @@ QString SieveEditorParsingMissingFeatureWarning::initialScript() const
 void SieveEditorParsingMissingFeatureWarning::slotShowDetails(const QString &content)
 {
     if (content == QLatin1String("sieveerrordetails")) {
-        QPointer<SieveScriptParsingErrorDialog> dlg = new SieveScriptParsingErrorDialog(this);
-        dlg->setError(mScript, mErrors);
-        dlg->exec();
-        delete dlg;
+        SieveScriptParsingErrorDialog dlg(this);
+        dlg.setError(mScript, mErrors);
+        dlg.exec();
     }
 }
 
