@@ -1,35 +1,23 @@
-/* Copyright (C) 2010 Torgny Nyblom <nyblom@kde.org>
- * Copyright (C) 2010-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2010 Torgny Nyblom <nyblom@kde.org>
+ * SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef FINDBARBASE_H
-#define FINDBARBASE_H
+#pragma once
 
-#include <QWidget>
 #include "ksieveui_export.h"
+#include <QWidget>
 class QAction;
 class QPushButton;
 class QMenu;
 class QLabel;
-namespace PimCommon {
+namespace PimCommon
+{
 class LineEditWithCompleterNg;
 }
-namespace KSieveUi {
+namespace KSieveUi
+{
 class KSIEVEUI_EXPORT FindBarBase : public QWidget
 {
     Q_OBJECT
@@ -81,4 +69,3 @@ protected:
 };
 }
 
-#endif /* FINDBARBASE_H */
