@@ -1,25 +1,12 @@
-/* Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "findbarwebengineview.h"
 #include <PimCommon/LineEditWithCompleterNg>
-#include <QWebEngineView>
 #include <QAction>
+#include <QWebEngineView>
 using namespace KSieveUi;
 
 class KSieveUi::FindBarWebEngineViewPrivate
@@ -41,7 +28,6 @@ FindBarWebEngineView::FindBarWebEngineView(QWebEngineView *view, QWidget *parent
 
 FindBarWebEngineView::~FindBarWebEngineView()
 {
-    delete d;
 }
 
 void FindBarWebEngineView::searchText(bool backward, bool isAutoSearch)
@@ -58,7 +44,7 @@ void FindBarWebEngineView::searchText(bool backward, bool isAutoSearch)
     if (!isAutoSearch && !mLastSearchStr.contains(searchWord, Qt::CaseSensitive)) {
         clearSelections();
     }
-    d->mView->findText(QString()); //Clear an existing highlight
+    d->mView->findText(QString()); // Clear an existing highlight
     mLastSearchStr = searchWord;
     d->mView->findText(mLastSearchStr, searchOptions, [this](bool found) {
         setFoundMatch(found);
@@ -70,7 +56,7 @@ void FindBarWebEngineView::updateSensitivity(bool sensitivity)
     QWebEnginePage::FindFlags searchOptions;
     if (sensitivity) {
         searchOptions |= QWebEnginePage::FindCaseSensitively;
-        d->mView->findText(QString()); //Clear an existing highligh
+        d->mView->findText(QString()); // Clear an existing highligh
     }
     d->mView->findText(QString(), searchOptions, [this](bool found) {
         setFoundMatch(found);
