@@ -34,7 +34,6 @@ CheckKolabKep14SupportJob::CheckKolabKep14SupportJob(QObject *parent)
 
 CheckKolabKep14SupportJob::~CheckKolabKep14SupportJob()
 {
-    delete d;
 }
 
 void CheckKolabKep14SupportJob::start()
@@ -78,7 +77,10 @@ bool CheckKolabKep14SupportJob::hasKep14Support() const
     return d->mKolabKep14Support;
 }
 
-void CheckKolabKep14SupportJob::slotCheckKep14Support(KManageSieve::SieveJob *job, bool success, const QStringList &availableScripts, const QString &activeScript)
+void CheckKolabKep14SupportJob::slotCheckKep14Support(KManageSieve::SieveJob *job,
+                                                      bool success,
+                                                      const QStringList &availableScripts,
+                                                      const QString &activeScript)
 {
     if (!success) {
         Q_EMIT result(this, false);
