@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "checkscriptjob.h"
@@ -26,15 +15,10 @@ using namespace KSieveUi;
 class KSieveUi::CheckScriptJobPrivate
 {
 public:
-    CheckScriptJobPrivate()
-        : mIsActive(false)
-    {
-    }
-
     QUrl mUrl;
     QString mOriginalScript;
     QString mCurrentScript;
-    bool mIsActive;
+    bool mIsActive = false;
 };
 
 CheckScriptJob::CheckScriptJob(QObject *parent)
@@ -43,10 +27,7 @@ CheckScriptJob::CheckScriptJob(QObject *parent)
 {
 }
 
-CheckScriptJob::~CheckScriptJob()
-{
-    delete d;
-}
+CheckScriptJob::~CheckScriptJob() = default;
 
 void CheckScriptJob::setOriginalScript(const QString &script)
 {
@@ -86,14 +67,14 @@ void CheckScriptJob::slotPutCheckSyntaxResult(KManageSieve::SieveJob *job, bool
         const QString errorMsg = job->errorString();
         Q_EMIT finished(errorMsg.isEmpty() ? i18n("An unknown error was encountered.") : errorMsg, false);
     }
-    //Put original script after check otherwise we will put a script even if we don't click on ok
+    // Put original script after check otherwise we will put a script even if we don't click on ok
     KManageSieve::SieveJob *restoreJob = KManageSieve::SieveJob::put(d->mUrl, d->mOriginalScript, d->mIsActive, d->mIsActive);
     connect(restoreJob, &KManageSieve::SieveJob::result, this, &CheckScriptJob::slotRestoreFile);
 }
 
 void CheckScriptJob::slotRestoreFile(KManageSieve::SieveJob *job, bool success)
 {
-    Q_UNUSED(job);
+    Q_UNUSED(job)
     if (!success) {
         qCWarning(LIBKSIEVE_LOG) << "Script can't be restored" << d->mUrl;
     }
