@@ -1,25 +1,14 @@
 /*
-  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "parseuserscriptjob.h"
 #include "ksieveui/scriptsparsing/parsingutil.h"
-#include <kmanagesieve/sievejob.h>
-#include <QXmlStreamReader>
 #include <KLocalizedString>
+#include <QXmlStreamReader>
+#include <kmanagesieve/sievejob.h>
 
 using namespace KSieveUi;
 ParseUserScriptJob::ParseUserScriptJob(const QUrl &url, QObject *parent)
@@ -71,8 +60,10 @@ void ParseUserScriptJob::slotGetResult(KManageSieve::SieveJob *job, bool success
 {
     mSieveJob = nullptr;
     if (!success) {
-        emitError(i18n("Retrieving the script failed.\n"
-                       "The server responded:\n%1", job->errorString()));
+        emitError(
+            i18n("Retrieving the script failed.\n"
+                 "The server responded:\n%1",
+                 job->errorString()));
         return;
     }
     if (script.isEmpty()) {
@@ -84,7 +75,7 @@ void ParseUserScriptJob::slotGetResult(KManageSieve::SieveJob *job, bool success
     if (result) {
         emitSuccess(lst);
     } else {
-        emitError(i18n("Script parsing error"));
+        emitError(i18n("Script parsing error."));
     }
 }
 
@@ -137,7 +128,7 @@ QStringList ParseUserScriptJob::extractActiveScript(const QString &doc)
                 if (mStreamReader->attributes().hasAttribute(QLatin1String("name"))) {
                     const QString actionName = mStreamReader->attributes().value(QLatin1String("name")).toString();
                     if (actionName == QLatin1String("include")) {
-                        //Load includes
+                        // Load includes
                         const QString str = loadInclude();
                         if (!str.isEmpty()) {
                             if (!lstScript.contains(str)) {
