@@ -1,35 +1,25 @@
 /*
-  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef KSIEVE_KSIEVEUI_MANAGESIEVESCRIPTSDIALOG_H
-#define KSIEVE_KSIEVEUI_MANAGESIEVESCRIPTSDIALOG_H
+#pragma once
 
-#include "ksieveui_export.h"
 #include "ksieveui/managesievewidget.h"
-
+#include "ksieveui_export.h"
 #include <QDialog>
+#include <memory>
 
 class QTreeWidgetItem;
 
-namespace KManageSieve {
+namespace KManageSieve
+{
 class SieveJob;
 }
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveEditor;
 class ManageSieveScriptsDialogPrivate;
 class SieveImapPasswordProvider;
@@ -62,14 +52,12 @@ private:
     void slotEditScript(const ManageSieveWidget::ScriptInfo &info);
     void slotNewScript(const ManageSieveWidget::ScriptInfo &info);
     void slotCheckScriptFinished(const QString &errorMsg, bool success);
-    void changeActiveScript(QTreeWidgetItem *, bool activate = true);
 
     void updateButtons(QTreeWidgetItem *item);
     void disableManagerScriptsDialog(bool disable);
 
 private:
-    ManageSieveScriptsDialogPrivate *const d;
+    std::unique_ptr<ManageSieveScriptsDialogPrivate> const d;
 };
 }
 
-#endif
