@@ -1,29 +1,16 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2017 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "xmlprintingscriptbuilder.h"
 #include <ksieve/parser.h>
 using KSieve::Parser;
 
-#include <ksieve/error.h>
 #include "libksieve_debug.h"
 #include <QXmlStreamWriter>
+#include <ksieve/error.h>
 
 using namespace KSieveUi;
 XMLPrintingScriptBuilder::XMLPrintingScriptBuilder(int indent)
@@ -33,8 +20,7 @@ XMLPrintingScriptBuilder::XMLPrintingScriptBuilder(int indent)
 }
 
 XMLPrintingScriptBuilder::XMLPrintingScriptBuilder()
-    : KSieve::ScriptBuilder(),
-      mStream(nullptr)
+    : KSieve::ScriptBuilder()
 {
     initialize();
 }
@@ -82,13 +68,9 @@ void XMLPrintingScriptBuilder::numberArgument(unsigned long number, char quantif
 
 void XMLPrintingScriptBuilder::commandStart(const QString &identifier, int lineNumber)
 {
-    Q_UNUSED(lineNumber);
-    if (identifier == QLatin1String("else") ||
-            identifier == QLatin1String("break") ||
-            identifier == QLatin1String("require") ||
-            identifier == QLatin1String("foreverypart") ||
-            identifier == QLatin1String("if") ||
-            identifier == QLatin1String("elsif")) {
+    Q_UNUSED(lineNumber)
+    if (identifier == QLatin1String("else") || identifier == QLatin1String("break") || identifier == QLatin1String("require")
+        || identifier == QLatin1String("foreverypart") || identifier == QLatin1String("if") || identifier == QLatin1String("elsif")) {
         mStream->writeStartElement(QStringLiteral("control"));
         mStream->writeAttribute(QStringLiteral("name"), identifier);
     } else {
@@ -99,7 +81,7 @@ void XMLPrintingScriptBuilder::commandStart(const QString &identifier, int lineN
 
 void XMLPrintingScriptBuilder::commandEnd(int lineNumber)
 {
-    Q_UNUSED(lineNumber);
+    Q_UNUSED(lineNumber)
     mStream->writeEndElement();
 }
 
@@ -126,13 +108,13 @@ void XMLPrintingScriptBuilder::testListEnd()
 
 void XMLPrintingScriptBuilder::blockStart(int lineNumber)
 {
-    Q_UNUSED(lineNumber);
+    Q_UNUSED(lineNumber)
     mStream->writeStartElement(QStringLiteral("block"));
 }
 
 void XMLPrintingScriptBuilder::blockEnd(int lineNumber)
 {
-    Q_UNUSED(lineNumber);
+    Q_UNUSED(lineNumber)
     mStream->writeEndElement();
 }
 
