@@ -1,36 +1,24 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVESCRIPTDEBUGGERFRONTENDWIDGET_H
-#define SIEVESCRIPTDEBUGGERFRONTENDWIDGET_H
+#pragma once
 
-#include <QWidget>
 #include "ksieveui_private_export.h"
+#include <QWidget>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
 class KUrlRequester;
 class QProcess;
 class QLineEdit;
 class QSplitter;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveTextEditWidget;
 class SieveScriptDebuggerWarning;
 class KSIEVEUI_TESTS_EXPORT SieveScriptDebuggerFrontEndWidget : public QWidget
@@ -38,7 +26,7 @@ class KSIEVEUI_TESTS_EXPORT SieveScriptDebuggerFrontEndWidget : public QWidget
     Q_OBJECT
 public:
     explicit SieveScriptDebuggerFrontEndWidget(QWidget *parent = nullptr);
-    ~SieveScriptDebuggerFrontEndWidget();
+    ~SieveScriptDebuggerFrontEndWidget() override;
 
     Q_REQUIRED_RESULT QString script() const;
     void setScript(const QString &script);
@@ -71,4 +59,3 @@ private:
     QSplitter *mSplitter = nullptr;
 };
 }
-#endif // SIEVESCRIPTDEBUGGERFONTENDWIDGET_H
