@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ABSTRACTAKONADIIMAPSETTINGINTERFACE_H
-#define ABSTRACTAKONADIIMAPSETTINGINTERFACE_H
+#pragma once
 
 #include "ksieveui_private_export.h"
 #include <QString>
-namespace KSieveUi {
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT AbstractAkonadiImapSettingInterface
 {
 public:
@@ -28,9 +28,9 @@ public:
     Q_REQUIRED_RESULT virtual int authentication() const;
     Q_REQUIRED_RESULT virtual QString sieveAlternateUrl() const;
     Q_REQUIRED_RESULT virtual int imapPort() const;
+
 private:
     Q_DISABLE_COPY(AbstractAkonadiImapSettingInterface)
 };
 }
 
-#endif // ABSTRACTAKONADIIMAPSETTINGINTERFACE_H
