@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef VACATIONUTILSTEST_H
-#define VACATIONUTILSTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -32,4 +31,3 @@ private Q_SLOTS:
     void testDisableGeneratedScript();
 };
 }
-#endif // VACATIONUTILSTEST_H
