@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 /*
@@ -22,8 +11,8 @@ See README for further information.
 
 */
 #include "vacationutils.h"
-#include "vacationscriptextractor.h"
 #include "sieve-vacation.h"
+#include "vacationscriptextractor.h"
 
 #include <QDate>
 #include <QRegularExpression>
@@ -32,7 +21,7 @@ using KMime::Types::AddrSpecList;
 using namespace KSieveUi::Legacy::VacationUtils;
 using namespace KSieveUi;
 
-static inline QString dotstuff(QString s)     // krazy:exclude=passbyvalue
+static inline QString dotstuff(QString s) // krazy:exclude=passbyvalue
 {
     if (s.startsWith(QLatin1Char('.'))) {
         return QLatin1Char('.') + s.replace(QLatin1String("\n."), QStringLiteral("\n.."));
@@ -43,7 +32,8 @@ static inline QString dotstuff(QString s)     // krazy:exclude=passbyvalue
 
 static inline QString stringReplace(QString s)
 {
-    s.replace(QRegularExpression(QStringLiteral("[\n\t]+")), QStringLiteral(" "));
+    static QRegularExpression reg(QStringLiteral("[\n\t]+"));
+    s.replace(reg, QStringLiteral(" "));
     return s.replace(QLatin1Char('\"'), QStringLiteral("\\\""));
 }
 
@@ -53,8 +43,15 @@ This file only contains legacy code, that can be removed if the legacy code is n
 See README for further information.
 
 */
-bool Legacy::VacationUtils::parseScript(const QString &script, QString &messageText, QString &subject, int &notificationInterval, AddrSpecList &aliases, bool &sendForSpam, QString &domainName,
-                                        QDate &startDate, QDate &endDate)
+bool Legacy::VacationUtils::parseScript(const QString &script,
+                                        QString &messageText,
+                                        QString &subject,
+                                        int &notificationInterval,
+                                        AddrSpecList &aliases,
+                                        bool &sendForSpam,
+                                        QString &domainName,
+                                        QDate &startDate,
+                                        QDate &endDate)
 {
     const QString trimmedScript = script.trimmed();
     if (trimmedScript.isEmpty()) {
@@ -66,8 +63,7 @@ bool Legacy::VacationUtils::parseScript(const QString &script, QString &messageT
     // the end, leading to a parse error.
     const QByteArray scriptUTF8 = trimmedScript.toUtf8();
     qCDebug(LIBKSIEVE_LOG) << "scriptUtf8 = \"" + scriptUTF8 + "\"";
-    KSieve::Parser parser(scriptUTF8.begin(),
-                          scriptUTF8.begin() + scriptUTF8.length());
+    KSieve::Parser parser(scriptUTF8.begin(), scriptUTF8.begin() + scriptUTF8.length());
     KSieveUi::Legacy::VacationDataExtractor vdx;
     KSieveUi::Legacy::SpamDataExtractor sdx;
     KSieveUi::Legacy::DomainRestrictionDataExtractor drdx;
@@ -104,8 +100,14 @@ This file only contains legacy code, that can be removed if the legacy code is n
 See README for further information.
 
 */
-QString Legacy::VacationUtils::composeScript(const QString &messageText, const QString &subject, int notificationInterval, const AddrSpecList &addrSpecs, bool sendForSpam, const QString &domain,
-                                             const QDate &startDate, const QDate &endDate)
+QString Legacy::VacationUtils::composeScript(const QString &messageText,
+                                             const QString &subject,
+                                             int notificationInterval,
+                                             const AddrSpecList &addrSpecs,
+                                             bool sendForSpam,
+                                             const QString &domain,
+                                             QDate startDate,
+                                             QDate endDate)
 {
     QString addressesArgument;
     QStringList aliases;
@@ -114,7 +116,9 @@ QString Legacy::VacationUtils::composeScript(const QString &messageText, const Q
         QStringList sl;
         AddrSpecList::const_iterator end = addrSpecs.constEnd();
         for (AddrSpecList::const_iterator it = addrSpecs.begin(); it != end; ++it) {
-            sl.push_back(QLatin1Char('"') + (*it).asString().replace(QLatin1Char('\\'), QStringLiteral("\\\\")).replace(QLatin1Char('"'), QStringLiteral("\\\"")) + QLatin1Char('"'));
+            sl.push_back(QLatin1Char('"')
+                         + (*it).asString().replace(QLatin1Char('\\'), QStringLiteral("\\\\")).replace(QLatin1Char('"'), QStringLiteral("\\\""))
+                         + QLatin1Char('"'));
             aliases.push_back((*it).asString());
         }
         addressesArgument += sl.join(QLatin1String(", ")) + QLatin1String(" ] ");
@@ -122,25 +126,28 @@ QString Legacy::VacationUtils::composeScript(const QString &messageText, const Q
 
     QString script = QStringLiteral("require \"vacation\";\n");
     if (startDate.isValid() && endDate.isValid()) {
-        script += QStringLiteral("require \"relational\";\n"
-                                 "require \"date\";\n\n");
+        script += QStringLiteral(
+            "require \"relational\";\n"
+            "require \"date\";\n\n");
     } else {
         script += QStringLiteral("\n");
     }
 
     if (!sendForSpam) {
-        script += QStringLiteral("if header :contains \"X-Spam-Flag\" \"YES\""
-                                 " { keep; stop; }\n");  // FIXME?
+        script += QStringLiteral(
+            "if header :contains \"X-Spam-Flag\" \"YES\""
+            " { keep; stop; }\n"); // FIXME?
     }
     if (!domain.isEmpty()) { // FIXME
         script += QStringLiteral("if not address :domain :contains \"from\" \"%1\" { keep; stop; }\n").arg(domain);
     }
 
     if (startDate.isValid() && endDate.isValid()) {
-        script += QStringLiteral("if not allof(currentdate :value \"ge\" \"date\" \"%1\","
-                                 " currentdate :value \"le\" \"date\" \"%2\")"
-                                 " { keep; stop; }\n").arg(startDate.toString(Qt::ISODate),
-                                                           endDate.toString(Qt::ISODate));
+        script += QStringLiteral(
+                      "if not allof(currentdate :value \"ge\" \"date\" \"%1\","
+                      " currentdate :value \"le\" \"date\" \"%2\")"
+                      " { keep; stop; }\n")
+                      .arg(startDate.toString(Qt::ISODate), endDate.toString(Qt::ISODate));
     }
 
     script += QLatin1String("vacation ");
