@@ -1,29 +1,18 @@
 /*
-  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "vacationcreatescriptjob.h"
 #include "vacationutils.h"
-#include <managescriptsjob/parseuserscriptjob.h>
-#include <managescriptsjob/generateglobalscriptjob.h>
 #include <kmanagesieve/sievejob.h>
+#include <managescriptsjob/generateglobalscriptjob.h>
+#include <managescriptsjob/parseuserscriptjob.h>
 
-#include <KMessageBox>
-#include <KLocalizedString>
 #include "libksieve_debug.h"
+#include <KLocalizedString>
+#include <KMessageBox>
 
 using namespace KSieveUi;
 
@@ -128,7 +117,7 @@ void VacationCreateScriptJob::slotGetScript(KManageSieve::SieveJob *job, bool su
     if (mKep14Support) {
         mSieveJob = KManageSieve::SieveJob::put(mUrl, mScript, false, false);
     } else {
-        mSieveJob = KManageSieve::SieveJob::put(mUrl, mScript, mActivate, false);           //Never deactivate
+        mSieveJob = KManageSieve::SieveJob::put(mUrl, mScript, mActivate, false); // Never deactivate
     }
     connect(mSieveJob, &KManageSieve::SieveJob::gotScript, this, &VacationCreateScriptJob::slotPutResult);
 }
@@ -146,16 +135,18 @@ void VacationCreateScriptJob::slotPutResult(KManageSieve::SieveJob *job, bool su
 
 void VacationCreateScriptJob::handleResult()
 {
-    if (mUserJobRunning || mScriptJobRunning) {                 // Not both jobs are done
+    if (mUserJobRunning || mScriptJobRunning) { // Not both jobs are done
         return;
     }
 
     if (mSuccess) {
-        KMessageBox::information(nullptr, mActivate
-                                 ? i18n("Sieve script installed successfully on the server \'%1\'.\n"
-                                        "Out of Office reply is now active.", mServerName)
-                                 : i18n("Sieve script installed successfully on the server \'%1\'.\n"
-                                        "Out of Office reply has been deactivated.", mServerName));
+        KMessageBox::information(nullptr,
+                                 mActivate ? i18n("Sieve script installed successfully on the server \'%1\'.\n"
+                                                  "Out of Office reply is now active.",
+                                                  mServerName)
+                                           : i18n("Sieve script installed successfully on the server \'%1\'.\n"
+                                                  "Out of Office reply has been deactivated.",
+                                                  mServerName));
     } else {
         KMessageBox::information(nullptr, i18n("Impossible to install script on server \'%1\'", mServerName));
     }
