@@ -1,49 +1,36 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "vacationeditwidget.h"
-#include "vacationutils.h"
 #include "vacationmailactionwidget.h"
 #include "vacationmaillineedit.h"
 
-#include <KLocalizedString>
 #include <KDateComboBox>
+#include <KLocalizedString>
 #include <KTimeComboBox>
-#include <QSpinBox>
 #include <QLineEdit>
 #include <QRegularExpressionValidator>
+#include <QSpinBox>
 
-#include <KPIMTextEdit/PlainTextEditorWidget>
-#include <KPIMTextEdit/PlainTextEditor>
 #include "libksieve_debug.h"
+#include <KPIMTextEdit/PlainTextEditor>
+#include <KPIMTextEdit/PlainTextEditorWidget>
+#include <Libkdepim/LineEditCatchReturnKey>
 
-#include <kmime/kmime_header_parsing.h>
+#include <KMime/HeaderParsing>
 
+#include <PimCommon/SpellCheckLineEdit>
 #include <QCheckBox>
 #include <QGridLayout>
 #include <QLabel>
-#include <PimCommon/SpellCheckLineEdit>
 
-using KMime::Types::AddrSpecList;
-using KMime::Types::AddressList;
-using KMime::Types::MailboxList;
 using KMime::HeaderParsing::parseAddressList;
+using KMime::Types::AddressList;
+using KMime::Types::AddrSpecList;
+using KMime::Types::MailboxList;
 
 using namespace KSieveUi;
 VacationEditWidget::VacationEditWidget(QWidget *parent)
@@ -51,14 +38,15 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
 {
     int row = -1;
 
-    QGridLayout *glay = new QGridLayout(this);
-    glay->setContentsMargins(0, 0, 0, 0);
+    auto glay = new QGridLayout(this);
+    glay->setContentsMargins({});
     glay->setColumnStretch(1, 1);
 
     // explanation label:
     ++row;
-    QLabel *configureVacationLabel = new QLabel(i18n("Configure vacation "
-                                                     "notifications to be sent:"), this);
+    auto configureVacationLabel = new QLabel(i18n("Configure vacation "
+                                                  "notifications to be sent:"),
+                                             this);
     configureVacationLabel->setObjectName(QStringLiteral("configureVacationLabel"));
     glay->addWidget(configureVacationLabel, row, 0, 1, 2);
 
@@ -82,15 +70,15 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     mSubject = new PimCommon::SpellCheckLineEdit(this, QString());
     mSubject->setObjectName(QStringLiteral("mSubject"));
     connect(mSubject, &PimCommon::SpellCheckLineEdit::textChanged, this, &VacationEditWidget::setWasChanged);
-    //mSubject->setClearButtonEnabled(true);
-    QLabel *subjectOfVacationLabel = new QLabel(i18n("&Subject of the vacation mail:"), this);
+    // mSubject->setClearButtonEnabled(true);
+    auto subjectOfVacationLabel = new QLabel(i18n("&Subject of the vacation mail:"), this);
     subjectOfVacationLabel->setObjectName(QStringLiteral("subjectOfVacationLabel"));
     subjectOfVacationLabel->setBuddy(mSubject);
     glay->addWidget(subjectOfVacationLabel, row, 0);
     glay->addWidget(mSubject, row, 1);
     ++row;
 
-    QHBoxLayout *timeLayout = new QHBoxLayout;
+    auto timeLayout = new QHBoxLayout;
     // Start date
     mStartDate = new KDateComboBox(this);
     mStartDate->setObjectName(QStringLiteral("mStartDate"));
@@ -157,7 +145,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
 
     // "Resent only after" spinbox and label:
     ++row;
-    int defDayInterval = 7; //default day interval
+    int defDayInterval = 7; // default day interval
     mIntervalSpin = new QSpinBox(this);
     mIntervalSpin->setMaximum(356);
     mIntervalSpin->setMinimum(1);
@@ -165,8 +153,8 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     mIntervalSpin->setValue(defDayInterval);
     mIntervalSpin->setObjectName(QStringLiteral("mIntervalSpin"));
     mIntervalSpin->setSuffix(i18np(" day", " days", defDayInterval));
-    connect(mIntervalSpin, QOverload<int>::of(&QSpinBox::valueChanged), this, &VacationEditWidget::slotIntervalSpinChanged);
-    QLabel *resendNotificationLabel = new QLabel(i18n("&Resend notification only after:"), this);
+    connect(mIntervalSpin, &QSpinBox::valueChanged, this, &VacationEditWidget::slotIntervalSpinChanged);
+    auto resendNotificationLabel = new QLabel(i18n("&Resend notification only after:"), this);
     resendNotificationLabel->setObjectName(QStringLiteral("resendNotificationLabel"));
     resendNotificationLabel->setBuddy(mIntervalSpin);
     glay->addWidget(resendNotificationLabel, row, 0);
@@ -178,7 +166,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     mMailAliasesEdit->setObjectName(QStringLiteral("mMailAliasesEdit"));
     mMailAliasesEdit->setClearButtonEnabled(true);
     connect(mMailAliasesEdit, &KSieveUi::VacationMailLineEdit::textChanged, this, &VacationEditWidget::setWasChanged);
-    QLabel *sendResponseLabel = new QLabel(i18n("&Send responses for these addresses:"), this);
+    auto sendResponseLabel = new QLabel(i18n("&Send responses for these addresses:"), this);
     sendResponseLabel->setObjectName(QStringLiteral("sendResponseLabel"));
     sendResponseLabel->setBuddy(mMailAliasesEdit);
     glay->addWidget(sendResponseLabel, row, 0);
@@ -190,21 +178,21 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
         mMailAction->addItem(VacationUtils::mailAction(static_cast<VacationUtils::MailAction>(i)));
     }
     mMailAction->setObjectName(QStringLiteral("mMailAction"));
-    connect(mMailAction, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &VacationEditWidget::mailActionChanged);
+    connect(mMailAction, &QComboBox::currentIndexChanged, this, &VacationEditWidget::mailActionChanged);
 
-    //Add imap select folder plugin here.
+    // Add imap select folder plugin here.
     mMailActionRecipient = new VacationMailActionWidget(this);
     mMailActionRecipient->setObjectName(QStringLiteral("mMailActionRecipient"));
     connect(mMailActionRecipient, &VacationMailActionWidget::wasChanged, this, &VacationEditWidget::setWasChanged);
-    //Add setChanged here too
+    // Add setChanged here too
 
-    QHBoxLayout *hLayout = new QHBoxLayout;
+    auto hLayout = new QHBoxLayout;
 
     hLayout->addWidget(mMailAction);
     hLayout->addWidget(mMailActionRecipient);
 
     ++row;
-    QLabel *actionIncomingMailsLabel = new QLabel(i18n("&Action for incoming mails:"), this);
+    auto actionIncomingMailsLabel = new QLabel(i18n("&Action for incoming mails:"), this);
     actionIncomingMailsLabel->setBuddy(mMailAction);
     actionIncomingMailsLabel->setObjectName(QStringLiteral("actionIncomingMailsLabel"));
     glay->addWidget(actionIncomingMailsLabel, row, 0);
@@ -226,6 +214,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     connect(mDomainCheck, &QCheckBox::clicked, this, &VacationEditWidget::setWasChanged);
 
     mDomainEdit = new QLineEdit(this);
+    new KPIM::LineEditCatchReturnKey(mDomainEdit, this);
     mDomainEdit->setObjectName(QStringLiteral("mDomainEdit"));
     mDomainEdit->setClearButtonEnabled(true);
     mDomainEdit->setEnabled(false);
@@ -299,10 +288,9 @@ AddrSpecList VacationEditWidget::mailAliases(bool &ok) const
 void VacationEditWidget::setMailAliases(const AddrSpecList &aliases)
 {
     QStringList sl;
-    AddrSpecList::const_iterator end(aliases.constEnd());
     sl.reserve(aliases.count());
-    for (AddrSpecList::const_iterator it = aliases.constBegin(); it != end; ++it) {
-        sl.push_back((*it).asString());
+    for (const auto &str : aliases) {
+        sl.push_back(str.asString());
     }
     mMailAliasesEdit->setText(sl.join(QLatin1String(", ")));
 }
@@ -356,7 +344,7 @@ QDate VacationEditWidget::endDate() const
     if (mEndDate->isEnabled()) {
         return mEndDate->date();
     } else {
-        return QDate();
+        return {};
     }
 }
 
@@ -370,7 +358,7 @@ QTime VacationEditWidget::endTime() const
     if (mEndTime->isEnabled()) {
         return mEndTime->time();
     } else {
-        return QTime();
+        return {};
     }
 }
 
@@ -386,7 +374,7 @@ QDate VacationEditWidget::startDate() const
     if (mStartDate->isEnabled()) {
         return mStartDate->date();
     } else {
-        return QDate();
+        return {};
     }
 }
 
@@ -400,7 +388,7 @@ QTime VacationEditWidget::startTime() const
     if (mStartTime->isEnabled()) {
         return mStartTime->time();
     } else {
-        return QTime();
+        return {};
     }
 }
 
