@@ -1,27 +1,13 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef VACATIONEDITWIDGET_H
-#define VACATIONEDITWIDGET_H
+#pragma once
 
-#include <QWidget>
 #include "vacationutils.h"
+#include <QWidget>
 class KDateComboBox;
 class KTimeComboBox;
 
@@ -36,24 +22,29 @@ class KDateComboBox;
 
 class QDate;
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
 
 class QCheckBox;
 
-namespace KMime {
-namespace Types {
+namespace KMime
+{
+namespace Types
+{
 struct AddrSpec;
-typedef QVector<AddrSpec> AddrSpecList;
+using AddrSpecList = QVector<AddrSpec>;
 }
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 class SpellCheckLineEdit;
 }
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class VacationMailActionWidget;
 class SieveImapAccountSettings;
 class VacationMailLineEdit;
@@ -62,7 +53,7 @@ class VacationEditWidget : public QWidget
     Q_OBJECT
 public:
     explicit VacationEditWidget(QWidget *parent = nullptr);
-    ~VacationEditWidget();
+    ~VacationEditWidget() override;
 
     void enableDomainAndSendForSpam(bool enable = true);
     void enableDates(bool enable = true);
@@ -144,4 +135,3 @@ protected:
 };
 }
 
-#endif // VACATIONEDITWIDGET_H
