@@ -1,30 +1,20 @@
 /*
-  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef VACATIONPAGEWIDGET_H
-#define VACATIONPAGEWIDGET_H
+#pragma once
 
-#include <QWidget>
 #include <QUrl>
+#include <QWidget>
 class QStackedWidget;
-namespace KManageSieve {
+namespace KManageSieve
+{
 }
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class VacationEditWidget;
 class VacationWarningWidget;
 class VacationCreateScriptJob;
@@ -35,7 +25,7 @@ class VacationPageWidget : public QWidget
     Q_OBJECT
 public:
     explicit VacationPageWidget(QWidget *parent = nullptr);
-    ~VacationPageWidget();
+    ~VacationPageWidget() override;
 
     void setServerUrl(const QUrl &url);
     void setServerName(const QString &serverName);
@@ -49,13 +39,7 @@ private Q_SLOTS:
     void slotGetResult(const QString &serverName, const QStringList &sieveCapabilities, const QString &scriptName, const QString &script, bool active);
 
 private:
-
-    void fillWithDefaults();
-
-    enum PageType {
-        Script = 0,
-        ScriptNotSupported = 1
-    };
+    enum PageType { Script = 0, ScriptNotSupported = 1 };
 
     QString mServerName;
     QUrl mUrl;
@@ -69,4 +53,3 @@ private:
 };
 }
 
-#endif // VACATIONPAGEWIDGET_H
