@@ -1,24 +1,10 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef VACATIONSCRIPTEXTRACTOR_H
-#define VACATIONSCRIPTEXTRACTOR_H
+#pragma once
 
 #include "sieve-vacation.h"
 #include "vacationutils.h"
@@ -34,12 +20,15 @@
 #include <set>
 #include <vector>
 
-namespace KSieveExt {
+namespace KSieveExt
+{
 class MultiScriptBuilder : public KSieve::ScriptBuilder
 {
     std::vector<KSieve::ScriptBuilder *> mBuilders;
+
 public:
-    MultiScriptBuilder() : KSieve::ScriptBuilder()
+    MultiScriptBuilder()
+        : KSieve::ScriptBuilder()
     {
     }
 
@@ -87,7 +76,7 @@ public:
         assert(sb4);
     }
 
-    ~MultiScriptBuilder()
+    ~MultiScriptBuilder() override
     {
     }
 
@@ -95,7 +84,9 @@ private:
 #ifdef FOREACH
 #undef FOREACH
 #endif
-#define FOREACH for (std::vector<KSieve::ScriptBuilder *>::const_iterator it = mBuilders.begin(), end = mBuilders.end(); it != end; ++it) (*it)->
+#define FOREACH                                                                                                                                                \
+    for (std::vector<KSieve::ScriptBuilder *>::const_iterator it = mBuilders.begin(), end = mBuilders.end(); it != end; ++it)                                  \
+    (*it)->
     void commandStart(const QString &identifier, int lineNumber) override
     {
         FOREACH commandStart(identifier, lineNumber);
@@ -195,7 +186,8 @@ private:
 };
 }
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class GenericInformationExtractor : public KSieve::ScriptBuilder
 {
 public:
@@ -274,9 +266,7 @@ private:
                 found = false;
             }
         }
-        qCDebug(LIBKSIEVE_LOG) << (found ? "found:" : "not found:")
-                               << mState << "->"
-                               << (found ? expected.if_found : expected.if_not_found);
+        qCDebug(LIBKSIEVE_LOG) << (found ? "found:" : "not found:") << mState << "->" << (found ? expected.if_found : expected.if_not_found);
         mState = found ? expected.if_found : expected.if_not_found;
         assert(mState < mNodes.size());
         if (found) {
@@ -406,42 +396,42 @@ private:
     }
 };
 
-typedef GenericInformationExtractor GIE;
+using GIE = GenericInformationExtractor;
 static const GenericInformationExtractor::StateNode spamNodes[] = {
-    { 0, GIE::CommandStart, "if", 1, 0, nullptr },               // 0
-    { 0, GIE::TestStart, "allof", 2, 3, nullptr },               // 1
-    { 0, GIE::TestListStart, nullptr, 3, 0, nullptr },                 // 2
-    { 0, GIE::TestStart, "not", 4, 3, nullptr },                 // 3
-    { 0, GIE::TestStart, "header", 5, 3, nullptr },              // 4
-    { 0, GIE::TaggedArgument, "contains", 6, 0, nullptr },       // 5
+    {0, GIE::CommandStart, "if", 1, 0, nullptr}, // 0
+    {0, GIE::TestStart, "allof", 2, 3, nullptr}, // 1
+    {0, GIE::TestListStart, nullptr, 3, 0, nullptr}, // 2
+    {0, GIE::TestStart, "not", 4, 3, nullptr}, // 3
+    {0, GIE::TestStart, "header", 5, 3, nullptr}, // 4
+    {0, GIE::TaggedArgument, "contains", 6, 0, nullptr}, // 5
 
     // accept both string and string-list:
-    { 0, GIE::StringArgument, "x-spam-flag", 12, 7, "x-spam-flag" },        // 6
-    { 0, GIE::StringListArgumentStart, nullptr, 8, 0, nullptr },                       // 7
-    { 0, GIE::StringListEntry, "x-spam-flag", 9, 10, "x-spam-flag" },       // 8
-    { 0, GIE::StringListEntry, nullptr, 9, 11, nullptr },                               // 9
-    { 0, GIE::StringListArgumentEnd, nullptr, 0, 8, nullptr },                         // 10
-    { 0, GIE::StringListArgumentEnd, nullptr, 12, 0, nullptr },                         // 11
+    {0, GIE::StringArgument, "x-spam-flag", 12, 7, "x-spam-flag"}, // 6
+    {0, GIE::StringListArgumentStart, nullptr, 8, 0, nullptr}, // 7
+    {0, GIE::StringListEntry, "x-spam-flag", 9, 10, "x-spam-flag"}, // 8
+    {0, GIE::StringListEntry, nullptr, 9, 11, nullptr}, // 9
+    {0, GIE::StringListArgumentEnd, nullptr, 0, 8, nullptr}, // 10
+    {0, GIE::StringListArgumentEnd, nullptr, 12, 0, nullptr}, // 11
 
     // accept both string and string-list:
-    { 0, GIE::StringArgument, "yes", 18, 13, "spam-flag-yes" },        // 12
-    { 0, GIE::StringListArgumentStart, nullptr, 14, 0, nullptr },                  // 13
-    { 0, GIE::StringListEntry, "yes", 15, 16, "spam-flag-yes" },       // 14
-    { 0, GIE::StringListEntry, nullptr, 15, 17, nullptr },                         // 15
-    { 0, GIE::StringListArgumentEnd, nullptr, 0, 14, nullptr },                    // 16
-    { 0, GIE::StringListArgumentEnd, nullptr, 18, 0, nullptr },                    // 17
+    {0, GIE::StringArgument, "yes", 18, 13, "spam-flag-yes"}, // 12
+    {0, GIE::StringListArgumentStart, nullptr, 14, 0, nullptr}, // 13
+    {0, GIE::StringListEntry, "yes", 15, 16, "spam-flag-yes"}, // 14
+    {0, GIE::StringListEntry, nullptr, 15, 17, nullptr}, // 15
+    {0, GIE::StringListArgumentEnd, nullptr, 0, 14, nullptr}, // 16
+    {0, GIE::StringListArgumentEnd, nullptr, 18, 0, nullptr}, // 17
 
-    { 0, GIE::TestEnd, nullptr, 21, 20, nullptr },       // 18
-    { 0, GIE::Any, nullptr, 21, 0, nullptr },            // 19
-    { 0, GIE::TestListEnd, nullptr, 21, 19, nullptr },   // 20
+    {0, GIE::TestEnd, nullptr, 21, 20, nullptr}, // 18
+    {0, GIE::Any, nullptr, 21, 0, nullptr}, // 19
+    {0, GIE::TestListEnd, nullptr, 21, 19, nullptr}, // 20
 
     // block of command, find "stop", take nested if's into account:
-    { 0, GIE::BlockStart, nullptr, 22, 18, nullptr },                         // 21
-    { 1, GIE::CommandStart, "vacation", 24, 22, "vacation" },     // 22
-    { 1, GIE::Any, nullptr, 24, 0, nullptr },                                 // 23
-    { 0, GIE::BlockEnd, nullptr, 25, 23, nullptr },                           // 24
+    {0, GIE::BlockStart, nullptr, 22, 18, nullptr}, // 21
+    {1, GIE::CommandStart, "vacation", 24, 22, "vacation"}, // 22
+    {1, GIE::Any, nullptr, 24, 0, nullptr}, // 23
+    {0, GIE::BlockEnd, nullptr, 25, 23, nullptr}, // 24
 
-    { -1, GIE::Any, nullptr, 25, 25, nullptr },   // 25 end state
+    {-1, GIE::Any, nullptr, 25, 25, nullptr}, // 25 end state
 };
 static const unsigned int numSpamNodes = sizeof spamNodes / sizeof *spamNodes;
 
@@ -455,9 +445,7 @@ public:
 
     bool found() const
     {
-        return mResults.count(QStringLiteral("x-spam-flag"))
-               && mResults.count(QStringLiteral("spam-flag-yes"))
-               && mResults.count(QStringLiteral("vacation"));
+        return mResults.count(QStringLiteral("x-spam-flag")) && mResults.count(QStringLiteral("spam-flag-yes")) && mResults.count(QStringLiteral("vacation"));
     }
 };
 
@@ -465,41 +453,41 @@ public:
 // libksieve/tests/parsertest
 //   'if not address :domain :contains ["from"] ["mydomain.org"] { keep; stop; }'
 static const GenericInformationExtractor::StateNode domainNodes[] = {
-    { 0, GIE::CommandStart, "if", 1, 0, nullptr },       // 0
-    { 0, GIE::TestStart, "allof", 2, 3, nullptr },       // 1
-    { 0, GIE::TestListStart, nullptr, 3, 0, nullptr },         // 2
-    { 0, GIE::TestStart, "address", 4, 3, nullptr },     // 3
+    {0, GIE::CommandStart, "if", 1, 0, nullptr}, // 0
+    {0, GIE::TestStart, "allof", 2, 3, nullptr}, // 1
+    {0, GIE::TestListStart, nullptr, 3, 0, nullptr}, // 2
+    {0, GIE::TestStart, "address", 4, 3, nullptr}, // 3
 
     // :domain and :contains in arbitrary order:
-    { 0, GIE::TaggedArgument, "domain", 5, 6, nullptr },           // 4
-    { 0, GIE::TaggedArgument, "contains", 8, 0, nullptr },         // 5
-    { 0, GIE::TaggedArgument, "contains", 7, 0, nullptr },         // 6
-    { 0, GIE::TaggedArgument, "domain", 8, 0, nullptr },           // 7
+    {0, GIE::TaggedArgument, "domain", 5, 6, nullptr}, // 4
+    {0, GIE::TaggedArgument, "contains", 8, 0, nullptr}, // 5
+    {0, GIE::TaggedArgument, "contains", 7, 0, nullptr}, // 6
+    {0, GIE::TaggedArgument, "domain", 8, 0, nullptr}, // 7
 
     // accept both string and string-list:
-    { 0, GIE::StringArgument, "from", 14, 9, "from" },           // 8
-    { 0, GIE::StringListArgumentStart, nullptr, 10, 0, nullptr },             // 9
-    { 0, GIE::StringListEntry, "from", 11, 12, "from" },         // 10
-    { 0, GIE::StringListEntry, nullptr, 11, 13, nullptr },                   // 11
-    { 0, GIE::StringListArgumentEnd, nullptr, 0, 10, nullptr },               // 12
-    { 0, GIE::StringListArgumentEnd, nullptr, 14, 0, nullptr },              // 13
+    {0, GIE::StringArgument, "from", 14, 9, "from"}, // 8
+    {0, GIE::StringListArgumentStart, nullptr, 10, 0, nullptr}, // 9
+    {0, GIE::StringListEntry, "from", 11, 12, "from"}, // 10
+    {0, GIE::StringListEntry, nullptr, 11, 13, nullptr}, // 11
+    {0, GIE::StringListArgumentEnd, nullptr, 0, 10, nullptr}, // 12
+    {0, GIE::StringListArgumentEnd, nullptr, 14, 0, nullptr}, // 13
 
     // string: save, string-list: save last
-    { 0, GIE::StringArgument, nullptr, 18, 15, "domainName" },          // 14
-    { 0, GIE::StringListArgumentStart, nullptr, 16, 0, nullptr },             // 15
-    { 0, GIE::StringListEntry, nullptr, 16, 17, "domainName" },         // 16
-    { 0, GIE::StringListArgumentEnd, nullptr, 18, 0, nullptr },               // 17
+    {0, GIE::StringArgument, nullptr, 18, 15, "domainName"}, // 14
+    {0, GIE::StringListArgumentStart, nullptr, 16, 0, nullptr}, // 15
+    {0, GIE::StringListEntry, nullptr, 16, 17, "domainName"}, // 16
+    {0, GIE::StringListArgumentEnd, nullptr, 18, 0, nullptr}, // 17
 
-    { 0, GIE::TestEnd, nullptr, 18, 20, nullptr },      // 18
-    { 0, GIE::Any, nullptr, 18, 0, nullptr },          // 19
+    {0, GIE::TestEnd, nullptr, 18, 20, nullptr}, // 18
+    {0, GIE::Any, nullptr, 18, 0, nullptr}, // 19
 
     // block of commands, find "stop", take nested if's into account:
-    { 0, GIE::BlockStart, nullptr, 21, 19, nullptr },                          // 20
-    { 1, GIE::CommandStart, "vacation", 23, 21, "vacation" },      // 21
-    { 1, GIE::Any, nullptr, 23, 0, nullptr },                                  // 22
-    { 0, GIE::BlockEnd, nullptr, 24, 22, nullptr },                            // 23
+    {0, GIE::BlockStart, nullptr, 21, 19, nullptr}, // 20
+    {1, GIE::CommandStart, "vacation", 23, 21, "vacation"}, // 21
+    {1, GIE::Any, nullptr, 23, 0, nullptr}, // 22
+    {0, GIE::BlockEnd, nullptr, 24, 22, nullptr}, // 23
 
-    { -1, GIE::Any, nullptr, 24, 24, nullptr }  // 24 end state
+    {-1, GIE::Any, nullptr, 24, 24, nullptr} // 24 end state
 };
 static const unsigned int numDomainNodes = sizeof domainNodes / sizeof *domainNodes;
 
@@ -513,61 +501,60 @@ public:
 
     QString domainName() /*not const, since map::op[] isn't const*/
     {
-        return mResults.count(QStringLiteral("vacation")) && mResults.count(QStringLiteral("from"))
-               ? mResults[QStringLiteral("domainName")] : QString();
+        return mResults.count(QStringLiteral("vacation")) && mResults.count(QStringLiteral("from")) ? mResults[QStringLiteral("domainName")] : QString();
     }
 };
 
 // if not allof (currentdate :value "ge" date "YYYY-MM-DD",
 //               currentfate :value "le" date "YYYY-MM-DD) { keep; stop; }
 static const GenericInformationExtractor::StateNode datesNodes[] = {
-    { 0, GIE::CommandStart, "if", 1, 0, nullptr },            // 0
-    { 0, GIE::TestStart, "allof", 2, 0, nullptr },            // 1
+    {0, GIE::CommandStart, "if", 1, 0, nullptr}, // 0
+    {0, GIE::TestStart, "allof", 2, 0, nullptr}, // 1
 
     // handle startDate and endDate in arbitrary order
-    { 0, GIE::TestListStart, nullptr, 3, 0, nullptr },                       // 2
-    { 0, GIE::TestStart, "currentdate", 4, 3, nullptr },                  // 3
-    { 0, GIE::TaggedArgument, "value", 5, 4, nullptr },                   // 4
-    { 0, GIE::StringArgument, "ge", 6, 10, nullptr },                     // 5
-    { 0, GIE::StringArgument, "date", 7, 8, nullptr },                    // 6
-    { 0, GIE::StringArgument, nullptr, 15, 0, "startDate" },              // 7
-    { 0, GIE::StringArgument, "iso8601", 9, 0, nullptr },                 // 8
-    { 0, GIE::StringArgument, nullptr, 15, 0, "startDateTime" },          // 9
-    { 0, GIE::StringArgument, "le", 11, 0, nullptr },                     // 10
-    { 0, GIE::StringArgument, "date", 12, 13, nullptr },                  // 11
-    { 0, GIE::StringArgument, nullptr, 15, 0, "endDate" },                // 12
-    { 0, GIE::StringArgument, "iso8601", 14, 0, nullptr },                // 13
-    { 0, GIE::StringArgument, nullptr, 15, 0, "endDateTime" },            // 14
-    { 0, GIE::TestEnd, nullptr, 16, 0, nullptr },                            // 15
+    {0, GIE::TestListStart, nullptr, 3, 0, nullptr}, // 2
+    {0, GIE::TestStart, "currentdate", 4, 3, nullptr}, // 3
+    {0, GIE::TaggedArgument, "value", 5, 4, nullptr}, // 4
+    {0, GIE::StringArgument, "ge", 6, 10, nullptr}, // 5
+    {0, GIE::StringArgument, "date", 7, 8, nullptr}, // 6
+    {0, GIE::StringArgument, nullptr, 15, 0, "startDate"}, // 7
+    {0, GIE::StringArgument, "iso8601", 9, 0, nullptr}, // 8
+    {0, GIE::StringArgument, nullptr, 15, 0, "startDateTime"}, // 9
+    {0, GIE::StringArgument, "le", 11, 0, nullptr}, // 10
+    {0, GIE::StringArgument, "date", 12, 13, nullptr}, // 11
+    {0, GIE::StringArgument, nullptr, 15, 0, "endDate"}, // 12
+    {0, GIE::StringArgument, "iso8601", 14, 0, nullptr}, // 13
+    {0, GIE::StringArgument, nullptr, 15, 0, "endDateTime"}, // 14
+    {0, GIE::TestEnd, nullptr, 16, 0, nullptr}, // 15
 
-    { 0, GIE::TestStart, "currentdate", 17, 16, nullptr },                // 16
-    { 0, GIE::TaggedArgument, "value", 18, 17, nullptr },                   // 17
-    { 0, GIE::StringArgument, "le", 19, 23, nullptr },                      // 18
-    { 0, GIE::StringArgument, "date", 20, 21, nullptr },                    // 19
-    { 0, GIE::StringArgument, nullptr, 28, 0, "endDate" },                  // 20
-    { 0, GIE::StringArgument, "iso8601", 22, 0, nullptr },                  // 21
-    { 0, GIE::StringArgument, nullptr, 28, 0, "endDateTime" },              // 22
-    { 0, GIE::StringArgument, "ge", 24, 0, nullptr },                       // 23
-    { 0, GIE::StringArgument, "date", 25, 26, nullptr },                    // 24
-    { 0, GIE::StringArgument, nullptr, 28, 0, "startDate" },                // 25
-    { 0, GIE::StringArgument, "iso8601", 27, 0, nullptr },                  // 26
-    { 0, GIE::StringArgument, nullptr, 28, 0, "startDateTime" },            // 27
-    { 0, GIE::TestEnd, nullptr, 32, 0, nullptr },                              // 28
-    { 0, GIE::TestStart, nullptr, 31, 30, nullptr },                // 29
-    { -1, GIE::Any, nullptr, 32, 0, nullptr },                               // 30
-    { 0, GIE::TestEnd, nullptr, 32, 30, nullptr },                // 31
-    { 0, GIE::TestListEnd, nullptr, 33, 29, nullptr },                        // 32
+    {0, GIE::TestStart, "currentdate", 17, 16, nullptr}, // 16
+    {0, GIE::TaggedArgument, "value", 18, 17, nullptr}, // 17
+    {0, GIE::StringArgument, "le", 19, 23, nullptr}, // 18
+    {0, GIE::StringArgument, "date", 20, 21, nullptr}, // 19
+    {0, GIE::StringArgument, nullptr, 28, 0, "endDate"}, // 20
+    {0, GIE::StringArgument, "iso8601", 22, 0, nullptr}, // 21
+    {0, GIE::StringArgument, nullptr, 28, 0, "endDateTime"}, // 22
+    {0, GIE::StringArgument, "ge", 24, 0, nullptr}, // 23
+    {0, GIE::StringArgument, "date", 25, 26, nullptr}, // 24
+    {0, GIE::StringArgument, nullptr, 28, 0, "startDate"}, // 25
+    {0, GIE::StringArgument, "iso8601", 27, 0, nullptr}, // 26
+    {0, GIE::StringArgument, nullptr, 28, 0, "startDateTime"}, // 27
+    {0, GIE::TestEnd, nullptr, 32, 0, nullptr}, // 28
+    {0, GIE::TestStart, nullptr, 31, 30, nullptr}, // 29
+    {-1, GIE::Any, nullptr, 32, 0, nullptr}, // 30
+    {0, GIE::TestEnd, nullptr, 32, 30, nullptr}, // 31
+    {0, GIE::TestListEnd, nullptr, 33, 29, nullptr}, // 32
 
-    { 0, GIE::TestEnd, nullptr, 34, 0, nullptr },                   // 33
+    {0, GIE::TestEnd, nullptr, 34, 0, nullptr}, // 33
 
     // block of commands, find "stop", take nested if's into account:
-    { 0, GIE::BlockStart, nullptr, 36, 33, nullptr },                   // 34
-    { -1, GIE::Any, nullptr, 36, 0, nullptr },                         // 35
-    { 1, GIE::CommandStart, "vacation", 38, 35, "vacation" },      // 36
-    { -1, GIE::Any, nullptr, 38, 0, nullptr },                         // 37
-    { 0, GIE::BlockEnd, nullptr, 39, 37, nullptr },                     // 38
+    {0, GIE::BlockStart, nullptr, 36, 33, nullptr}, // 34
+    {-1, GIE::Any, nullptr, 36, 0, nullptr}, // 35
+    {1, GIE::CommandStart, "vacation", 38, 35, "vacation"}, // 36
+    {-1, GIE::Any, nullptr, 38, 0, nullptr}, // 37
+    {0, GIE::BlockEnd, nullptr, 39, 37, nullptr}, // 38
 
-    { -1, GIE::Any, nullptr, 39, 39, nullptr }                      // 39 end state
+    {-1, GIE::Any, nullptr, 39, 39, nullptr} // 39 end state
 };
 
 static const unsigned int numDatesNodes = sizeof datesNodes / sizeof *datesNodes;
@@ -612,7 +599,7 @@ private:
     QDate date(const QString &name) const
     {
         if (results().count(name) == 0) {
-            return QDate();
+            return {};
         } else {
             return QDate::fromString(results().at(name), Qt::ISODate);
         }
@@ -635,11 +622,14 @@ class VacationDataExtractor : public KSieve::ScriptBuilder
         // command itself:
         VacationCommand,
         // tagged args:
-        Days, Addresses, Subject,
+        Days,
+        Addresses,
+        Subject,
         VacationEnd,
         IfBlock,
         RedirectCommand
     };
+
 public:
     VacationDataExtractor();
     ~VacationDataExtractor() override;
@@ -742,21 +732,21 @@ private:
     void stringListArgumentEnd() override;
 
 private:
-    Context mContext;
-    int mNotificationInterval;
+    Context mContext = None;
+    int mNotificationInterval = 0;
     QString mMessageText;
     QString mSubject;
     QStringList mAliases;
-    bool mActive;
-    bool mInIfBlock;
-    bool mFoundInBlock;
-    int mBlockLevel;
+    bool mActive = true;
+    bool mInIfBlock = false;
+    bool mFoundInBlock = false;
+    int mBlockLevel = 0;
     QString mIfComment;
-    int mLineStart;
-    int mLineEnd;
+    int mLineStart = 0;
+    int mLineEnd = 0;
 
-    VacationUtils::MailAction mMailAction;
-    Context mMailActionContext;
+    VacationUtils::MailAction mMailAction = VacationUtils::Keep;
+    Context mMailActionContext = None;
     QString mMailActionRecipient;
 
     void reset();
@@ -770,6 +760,7 @@ class RequireExtractor : public KSieve::ScriptBuilder
         RequireCommand,
         EndState
     };
+
 public:
     RequireExtractor();
     ~RequireExtractor() override;
@@ -869,4 +860,3 @@ private:
 };
 }
 
-#endif // VACATIONSCRIPTEXTRACTOR_H
