@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef ABSTRACTMOVEIMAPFOLDERWIDGET_H
-#define ABSTRACTMOVEIMAPFOLDERWIDGET_H
+#pragma once
 
-#include <QWidget>
 #include "ksieveui_export.h"
-namespace KSieveUi {
+#include <QWidget>
+namespace KSieveUi
+{
 class SieveImapAccountSettings;
 /**
  * @brief The AbstractMoveImapFolderWidget class
@@ -20,7 +20,7 @@ class KSIEVEUI_EXPORT AbstractMoveImapFolderWidget : public QWidget
     Q_OBJECT
 public:
     explicit AbstractMoveImapFolderWidget(QWidget *parent = nullptr);
-    ~AbstractMoveImapFolderWidget();
+    ~AbstractMoveImapFolderWidget() override;
 
     virtual void setText(const QString &str) = 0;
     virtual QString text() const = 0;
@@ -30,4 +30,3 @@ Q_SIGNALS:
 };
 }
 
-#endif // ABSTRACTMOVEIMAPFOLDERWIDGET_H
