@@ -1,30 +1,28 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef INCLUDEFILELINEEDIT_H
-#define INCLUDEFILELINEEDIT_H
+#pragma once
 
-#include "lineeditvalidator.h"
 #include "ksieveui_private_export.h"
+#include "lineeditvalidator.h"
 class QCompleter;
 class QStringListModel;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT IncludeFileLineEdit : public LineEditValidator
 {
     Q_OBJECT
 public:
     explicit IncludeFileLineEdit(QWidget *parent = nullptr);
-    ~IncludeFileLineEdit();
+    ~IncludeFileLineEdit() override;
 
     void setListOfIncludeFile(const QStringList &lst);
 
 private:
-    void initialize();
-    QCompleter *mCompleter = nullptr;
+    QCompleter *const mCompleter;
     QStringListModel *mStringListModel = nullptr;
 };
 }
-#endif // INCLUDEFILELINEEDIT_H
