@@ -1,43 +1,32 @@
 /*
-  Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "managesievewidget.h"
+#include "libksieve_debug.h"
+#include "managescriptsjob/renamescriptjob.h"
 #include "managesievetreeview.h"
 #include "widgets/sievetreewidgetitem.h"
-#include "managescriptsjob/renamescriptjob.h"
-#include "libksieve_debug.h"
 
-#include <kmanagesieve/sievejob.h>
-#include <managescriptsjob/parseuserscriptjob.h>
-#include <managescriptsjob/generateglobalscriptjob.h>
 #include <PimCommon/NetworkManager>
+#include <kmanagesieve/sievejob.h>
+#include <managescriptsjob/generateglobalscriptjob.h>
+#include <managescriptsjob/parseuserscriptjob.h>
 
 #include "util/util_p.h"
 
-#include <QInputDialog>
-#include <KStandardGuiItem>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KStandardGuiItem>
+#include <QInputDialog>
 
 #include <QHBoxLayout>
 #include <QMenu>
-#include <QTimer>
 #include <QMetaType>
 #include <QNetworkConfigurationManager>
+#include <QTimer>
 //#define USE_RENAME_SIEVE_METHOD 1
 using namespace KSieveUi;
 Q_DECLARE_METATYPE(QTreeWidgetItem *)
@@ -46,8 +35,7 @@ class KSieveUi::ManageSieveWidgetPrivate
 {
 public:
     ManageSieveWidgetPrivate()
-        : mTreeView(nullptr)
-        , mClearAll(false)
+        : mClearAll(false)
         , mBlockSignal(false)
     {
     }
@@ -67,8 +55,8 @@ ManageSieveWidget::ManageSieveWidget(QWidget *parent)
     : QWidget(parent)
     , d(new KSieveUi::ManageSieveWidgetPrivate)
 {
-    QHBoxLayout *lay = new QHBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto lay = new QHBoxLayout(this);
+    lay->setContentsMargins({});
 
     d->mTreeView = new ManageSieveTreeView(this);
 #ifndef QT_NO_CONTEXTMENU
@@ -77,8 +65,12 @@ ManageSieveWidget::ManageSieveWidget(QWidget *parent)
     connect(d->mTreeView, &ManageSieveTreeView::itemDoubleClicked, this, &ManageSieveWidget::slotDoubleClicked);
     connect(d->mTreeView, &ManageSieveTreeView::itemSelectionChanged, this, &ManageSieveWidget::slotUpdateButtons);
     connect(d->mTreeView, &ManageSieveTreeView::itemChanged, this, &ManageSieveWidget::slotItemChanged);
+    connect(this, &ManageSieveWidget::updateSieveSettingsDone, this, &ManageSieveWidget::updateSieveSettingsFinished);
 
-    connect(PimCommon::NetworkManager::self()->networkConfigureManager(), &QNetworkConfigurationManager::onlineStateChanged, this, &ManageSieveWidget::slotSystemNetworkOnlineStateChanged);
+    connect(PimCommon::NetworkManager::self()->networkConfigureManager(),
+            &QNetworkConfigurationManager::onlineStateChanged,
+            this,
+            &ManageSieveWidget::slotSystemNetworkOnlineStateChanged);
 
     lay->addWidget(d->mTreeView);
     QTimer::singleShot(0, this, &ManageSieveWidget::slotCheckNetworkStatus);
@@ -88,7 +80,6 @@ ManageSieveWidget::~ManageSieveWidget()
 {
     disconnect(d->mTreeView, &ManageSieveTreeView::itemSelectionChanged, this, &ManageSieveWidget::slotUpdateButtons);
     clear();
-    delete d;
 }
 
 void ManageSieveWidget::slotCheckNetworkStatus()
@@ -173,7 +164,7 @@ void ManageSieveWidget::slotContextMenuRequested(const QPoint &p)
         const bool jobsListIsEmpty = mJobs.keys(item).isEmpty();
         if (canAddNewScript(item, jobsListIsEmpty)) {
             menu.addAction(QIcon::fromTheme(QStringLiteral("document-new")), i18n("New Script..."), this, &ManageSieveWidget::slotNewScript);
-        } else if (!jobsListIsEmpty) { //In Progress
+        } else if (!jobsListIsEmpty) { // In Progress
             menu.addAction(KStandardGuiItem::cancel().icon(), KStandardGuiItem::cancel().text(), this, &ManageSieveWidget::slotCancelFetch);
         }
     }
@@ -236,9 +227,8 @@ void ManageSieveWidget::slotNewScript()
     }
 
     bool ok = false;
-    QString name = QInputDialog::getText(this, i18n("New Sieve Script"),
-                                         i18n("Please enter a name for the new Sieve script:"), QLineEdit::Normal,
-                                         i18n("unnamed"), &ok);
+    QString name =
+        QInputDialog::getText(this, i18n("New Sieve Script"), i18n("Please enter a name for the new Sieve script:"), QLineEdit::Normal, i18n("unnamed"), &ok);
     name = name.trimmed();
     if (!ok || name.isEmpty()) {
         if (ok && name.isEmpty()) {
@@ -260,21 +250,18 @@ void ManageSieveWidget::slotNewScript()
         const int numberOfElement(parentItem->childCount());
         for (int i = 0; i < numberOfElement; ++i) {
             if (parentItem->child(i)->text(0) == name) {
-                KMessageBox::error(
-                    this,
-                    i18n("Script name already used \"%1\".", name),
-                    i18n("New Script"));
+                KMessageBox::error(this, i18n("Script name already used \"%1\".", name), i18n("New Script"));
                 return;
             }
         }
     }
 
     const QStringList currentCapabilities = currentItem->data(0, SIEVE_SERVER_CAPABILITIES).toStringList();
-    const KSieveUi::SieveImapAccountSettings sieveimapaccountsettings = currentItem->data(0, SIEVE_SERVER_IMAP_SETTINGS).value<KSieveUi::SieveImapAccountSettings>();
+    const auto sieveimapaccountsettings = currentItem->data(0, SIEVE_SERVER_IMAP_SETTINGS).value<KSieveUi::SieveImapAccountSettings>();
     const QStringList listscript = currentItem->data(0, SIEVE_SERVER_LIST_SCRIPT).toStringList();
 
     d->mBlockSignal = true;
-    QTreeWidgetItem *newItem = new QTreeWidgetItem(currentItem);
+    auto newItem = new QTreeWidgetItem(currentItem);
     newItem->setFlags(newItem->flags() & (Qt::ItemIsUserCheckable | Qt::ItemIsEnabled | Qt::ItemIsSelectable));
     newItem->setText(0, name);
     newItem->setCheckState(0, Qt::Unchecked);
@@ -304,8 +291,8 @@ void ManageSieveWidget::slotEditScript()
         return;
     }
     url = url.adjusted(QUrl::RemoveFilename);
-    url.setPath(url.path() +  QLatin1Char('/') + currentItem->text(0));
-    const KSieveUi::SieveImapAccountSettings sieveimapaccountsettings = parent->data(0, SIEVE_SERVER_IMAP_SETTINGS).value<KSieveUi::SieveImapAccountSettings>();
+    url.setPath(url.path() + QLatin1Char('/') + currentItem->text(0));
+    const auto sieveimapaccountsettings = parent->data(0, SIEVE_SERVER_IMAP_SETTINGS).value<KSieveUi::SieveImapAccountSettings>();
     const QStringList currentCapabilities = parent->data(0, SIEVE_SERVER_CAPABILITIES).toStringList();
     const QStringList listscript = parent->data(0, SIEVE_SERVER_LIST_SCRIPT).toStringList();
 
@@ -331,7 +318,28 @@ void ManageSieveWidget::slotDeactivateScript()
     }
 }
 
-void ManageSieveWidget::changeActiveScript(QTreeWidgetItem *item, bool activate)
+bool ManageSieveWidget::updateGlobalScript(QTreeWidgetItem *item, const QUrl &u)
+{
+    if (item->data(0, SIEVE_SERVER_MODE).toInt() == Kep14EditorMode) {
+        QStringList activeScripts;
+        for (int i = 0; i < item->childCount(); ++i) {
+            QTreeWidgetItem *j = item->child(i);
+            if (itemIsActived(j)) {
+                activeScripts << j->text(0);
+            }
+        }
+        auto job = new GenerateGlobalScriptJob(u);
+        job->addUserActiveScripts(activeScripts);
+        job->setForceActivateUserScript(true);
+        connect(job, &GenerateGlobalScriptJob::success, this, &ManageSieveWidget::slotRefresh);
+        connect(job, &GenerateGlobalScriptJob::error, this, &ManageSieveWidget::slotGenerateGlobalScriptError);
+        job->start();
+        return true;
+    }
+    return false;
+}
+
+void ManageSieveWidget::changeActiveScript(QTreeWidgetItem *item, bool activate, bool deleteScript)
 {
     if (!item) {
         return;
@@ -346,20 +354,7 @@ void ManageSieveWidget::changeActiveScript(QTreeWidgetItem *item, bool activate)
     if (u.isEmpty()) {
         return;
     }
-
-    if (item->data(0, SIEVE_SERVER_MODE).toInt() == Kep14EditorMode) {
-        QStringList activeScripts;
-        for (int i = 0; i < item->childCount(); ++i) {
-            QTreeWidgetItem *j = item->child(i);
-            if (itemIsActived(j)) {
-                activeScripts << j->text(0);
-            }
-        }
-        GenerateGlobalScriptJob *job = new GenerateGlobalScriptJob(u);
-        job->addUserActiveScripts(activeScripts);
-        connect(job, &GenerateGlobalScriptJob::success, this, &ManageSieveWidget::slotRefresh);
-        connect(job, &GenerateGlobalScriptJob::error, this, &ManageSieveWidget::slotGenerateGlobalScriptError);
-        job->start();
+    if (updateGlobalScript(item, u)) {
         return;
     }
 
@@ -368,7 +363,7 @@ void ManageSieveWidget::changeActiveScript(QTreeWidgetItem *item, bool activate)
         return;
     }
     u = u.adjusted(QUrl::RemoveFilename);
-    u.setPath(u.path() +  QLatin1Char('/') + selected->text(0));
+    u.setPath(u.path() + QLatin1Char('/') + selected->text(0));
 
     KManageSieve::SieveJob *job = nullptr;
     if (activate) {
@@ -377,7 +372,14 @@ void ManageSieveWidget::changeActiveScript(QTreeWidgetItem *item, bool activate)
         job = KManageSieve::SieveJob::deactivate(u);
     }
     d->mBlockSignal = true;
-    connect(job, &KManageSieve::SieveJob::result, this, &ManageSieveWidget::slotRefresh);
+    connect(job, &KManageSieve::SieveJob::result, this, [this, u, deleteScript]() {
+        slotRefresh();
+        if (deleteScript) {
+            KManageSieve::SieveJob *job = KManageSieve::SieveJob::del(u);
+            connect(job, &KManageSieve::SieveJob::result, this, &ManageSieveWidget::slotDeleteResult);
+            Q_EMIT scriptDeleted(u);
+        }
+    });
 }
 
 void ManageSieveWidget::slotGenerateGlobalScriptError(const QString &errorStr)
@@ -438,12 +440,12 @@ void ManageSieveWidget::slotRenameScript()
     }
 
     u = u.adjusted(QUrl::RemoveFilename);
-    u.setPath(u.path() +  QLatin1Char('/') + currentItem->text(0));
+    u.setPath(u.path() + QLatin1Char('/') + currentItem->text(0));
 #ifdef USE_RENAME_SIEVE_METHOD
     KManageSieve::SieveJob *job = KManageSieve::SieveJob::rename(u, newName);
     connect(job, &KManageSieve::SieveJob::result, this, &ManageSieveWidget::slotRenameResult);
 #else
-    KSieveUi::RenameScriptJob *job = new KSieveUi::RenameScriptJob(this);
+    auto job = new KSieveUi::RenameScriptJob(this);
     job->setOldUrl(u);
     job->setIsActive(itemIsActived(currentItem));
     job->setNewName(newName);
@@ -465,7 +467,7 @@ void ManageSieveWidget::slotRenameFinished(const QUrl &oldUrl, const QUrl &newUr
 
 void ManageSieveWidget::slotRenameResult(KManageSieve::SieveJob *job, bool success)
 {
-    Q_UNUSED(job);
+    Q_UNUSED(job)
     qCDebug(LIBKSIEVE_LOG) << " void ManageSieveWidget::slotRenameResult(KManageSieve::SieveJob *job, bool success)" << success;
     slotRefresh();
 }
@@ -491,7 +493,8 @@ void ManageSieveWidget::slotDeleteScript()
         return;
     }
 
-    if (KMessageBox::warningContinueCancel(this, i18n("Really delete script \"%1\" from the server?", currentItem->text(0)),
+    if (KMessageBox::warningContinueCancel(this,
+                                           i18n("Really delete script \"%1\" from the server?", currentItem->text(0)),
                                            i18n("Delete Sieve Script Confirmation"),
                                            KStandardGuiItem::del())
         != KMessageBox::Continue) {
@@ -499,7 +502,7 @@ void ManageSieveWidget::slotDeleteScript()
     }
 
     u = u.adjusted(QUrl::RemoveFilename);
-    u.setPath(u.path() +  QLatin1Char('/') + currentItem->text(0));
+    u.setPath(u.path() + QLatin1Char('/') + currentItem->text(0));
 
     KManageSieve::SieveJob *job = KManageSieve::SieveJob::del(u);
     connect(job, &KManageSieve::SieveJob::result, this, &ManageSieveWidget::slotDeleteResult);
@@ -509,8 +512,11 @@ void ManageSieveWidget::slotDeleteScript()
 void ManageSieveWidget::slotDeleteResult(KManageSieve::SieveJob *job, bool success)
 {
     if (!success) {
-        KMessageBox::error(this, i18n("Deleting the script failed.\n"
-                                      "The server responded:\n%1", job->errorString()), i18n("Sieve Error"));
+        KMessageBox::error(this,
+                           i18n("Deleting the script failed.\n"
+                                "The server responded:\n%1",
+                                job->errorString()),
+                           i18n("Sieve Error"));
     }
     slotRefresh();
 }
@@ -518,6 +524,11 @@ void ManageSieveWidget::slotDeleteResult(KManageSieve::SieveJob *job, bool succe
 void ManageSieveWidget::slotRefresh()
 {
     d->mBlockSignal = true;
+    updateSieveSettings();
+}
+
+void ManageSieveWidget::updateSieveSettingsFinished()
+{
     clear();
     const bool noImapFound = refreshList();
     slotUpdateButtons();
@@ -535,14 +546,15 @@ void ManageSieveWidget::slotUpdateButtons()
 
 void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, const QStringList &listScript, const QString &activeScript)
 {
-    //qCDebug(LIBKSIEVE_LOG) << "void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, const QStringList &listScript, const QString &activeScript) success: " << success
+    // qCDebug(LIBKSIEVE_LOG) << "void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, const QStringList &listScript, const QString
+    // &activeScript) success: " << success
     //                       << " listScript" << listScript;
     if (d->mClearAll) {
         return;
     }
-    //qCDebug(LIBKSIEVE_LOG) << " After mClear All";
+    // qCDebug(LIBKSIEVE_LOG) << " After mClear All";
     QTreeWidgetItem *parent = mJobs[job];
-    //qCDebug(LIBKSIEVE_LOG) << " parent " << parent;
+    // qCDebug(LIBKSIEVE_LOG) << " parent " << parent;
     if (!parent) {
         return;
     }
@@ -552,7 +564,7 @@ void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, c
     if (!success) {
         d->mBlockSignal = false;
         parent->setData(0, SIEVE_SERVER_ERROR, true);
-        QTreeWidgetItem *item = new QTreeWidgetItem(parent);
+        auto item = new QTreeWidgetItem(parent);
         item->setText(0, i18n("Failed to fetch the list of scripts"));
         item->setFlags(item->flags() & ~Qt::ItemIsEnabled);
         d->mTreeView->expandItem(parent);
@@ -561,11 +573,11 @@ void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, c
 
     d->mBlockSignal = true; // don't trigger slotItemChanged
     for (const QString &script : listScript) {
-        //Hide protected name.
+        // Hide protected name.
         if (Util::isKep14ProtectedName(script)) {
             continue;
         }
-        QTreeWidgetItem *item = new QTreeWidgetItem(parent);
+        auto item = new QTreeWidgetItem(parent);
         item->setFlags(item->flags() & (Qt::ItemIsUserCheckable | Qt::ItemIsEnabled | Qt::ItemIsSelectable));
 
         item->setText(0, script);
@@ -582,13 +594,13 @@ void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, c
         QUrl u = mUrls[parent];
         u = u.adjusted(QUrl::RemoveFilename);
         u.setPath(u.path() + QLatin1Char('/') + QStringLiteral("USER"));
-        ParseUserScriptJob *parseJob = new ParseUserScriptJob(u, this);
+        auto parseJob = new ParseUserScriptJob(u, this);
         parseJob->setAutoDelete(true);
         parseJob->setProperty("parentItem", QVariant::fromValue<QTreeWidgetItem *>(parent));
         connect(parseJob, &ParseUserScriptJob::finished, this, &ManageSieveWidget::setActiveScripts);
         parseJob->start();
         (static_cast<SieveTreeWidgetItem *>(parent))->startAnimation();
-    } else if (Util::hasKep14CapabilitySupport(job->sieveCapabilities())) { //We don't have user script but server support kep14
+    } else if (Util::hasKep14CapabilitySupport(job->sieveCapabilities())) { // We don't have user script but server support kep14
         hasKep14EditorMode = true;
     }
 
@@ -602,7 +614,7 @@ void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, c
 
 void ManageSieveWidget::setActiveScripts(ParseUserScriptJob *job)
 {
-    QTreeWidgetItem *parent = job->property("parentItem").value<QTreeWidgetItem *>();
+    auto *parent = job->property("parentItem").value<QTreeWidgetItem *>();
     if (!parent) {
         return;
     }
@@ -625,11 +637,11 @@ void ManageSieveWidget::setActiveScripts(ParseUserScriptJob *job)
         const bool isActive = activeScriptList.contains(item->text(0));
         item->setCheckState(0, isActive ? Qt::Checked : Qt::Unchecked);
         if (!isActive) {
-            scriptOrder <<  item->text(0);
+            scriptOrder << item->text(0);
         }
     }
 
-    for (const QString &scriptName : qAsConst(scriptOrder)) {
+    for (const QString &scriptName : std::as_const(scriptOrder)) {
         parent->addChild(scriptMap[scriptName]);
     }
 
