@@ -3,46 +3,25 @@
 
     This file is part of KSieve,
     the KDE internet mail/usenet news message filtering library.
-    Copyright (c) 2002-2003 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2002-2003 Marc Mutz <mutz@kde.org>
 
-    KSieve is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License, version 2, as
-    published by the Free Software Foundation.
-
-    KSieve is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-only
 */
 
-#include <ksieve/parser.h>
 #include <impl/parser.h>
+#include <ksieve/parser.h>
 
 #include <ksieve/error.h>
 
-#include <QString>
 #include <QByteArray>
+#include <QString>
 
 #include <assert.h>
-#include <limits.h> // ULONG_MAX
 #include <ctype.h> // isdigit
+#include <limits.h> // ULONG_MAX
 
-namespace KSieve {
+namespace KSieve
+{
 //
 //
 // Parser Bridge implementation
@@ -50,9 +29,8 @@ namespace KSieve {
 //
 
 Parser::Parser(const char *scursor, const char *const send, int options)
-    : i(nullptr)
+    : i(new Impl(scursor, send, options))
 {
-    i = new Impl(scursor, send, options);
 }
 
 Parser::~Parser()
@@ -99,18 +77,19 @@ static inline unsigned long factorForQuantifier(char ch)
     case 'K':
         return 1024;
     default:
-        assert(0);   // lexer should prohibit this
+        assert(0); // lexer should prohibit this
         return 1; // make compiler happy
     }
 }
 
 static inline bool willOverflowULong(unsigned long result, unsigned long add)
 {
-    static const unsigned long maxULongByTen = (unsigned long)(ULONG_MAX / 10.0);
+    static const auto maxULongByTen = (unsigned long)(ULONG_MAX / 10.0);
     return result > maxULongByTen || ULONG_MAX - 10 * result < add;
 }
 
-namespace KSieve {
+namespace KSieve
+{
 //
 //
 // Parser Implementation
@@ -126,16 +105,12 @@ Parser::Impl::Impl(const char *scursor, const char *const send, int options)
 
 bool Parser::Impl::isStringToken() const
 {
-    return token() == Lexer::QuotedString
-           || token() == Lexer::MultiLineString;
+    return token() == Lexer::QuotedString || token() == Lexer::MultiLineString;
 }
 
 bool Parser::Impl::isArgumentToken() const
 {
-    return isStringToken()
-           || token() == Lexer::Number
-           || token() == Lexer::Tag
-           || (token() == Lexer::Special && mTokenValue == QLatin1String("["));
+    return isStringToken() || token() == Lexer::Number || token() == Lexer::Tag || (token() == Lexer::Special && mTokenValue == QLatin1String("["));
 }
 
 bool Parser::Impl::obtainToken()
@@ -170,8 +145,7 @@ bool Parser::Impl::obtainToken()
             }
             consumeToken();
             break;
-        default:
-            ;     // make compiler happy
+        default:; // make compiler happy
         }
     }
     if (lexer.error() && scriptBuilder()) {
@@ -199,7 +173,7 @@ bool Parser::Impl::parse()
 bool Parser::Impl::parseCommandList()
 {
     // our ABNF:
-    // command-list := *comand
+    // command-list := *command
 
     while (!atEnd()) {
         if (!obtainToken()) {
@@ -275,12 +249,12 @@ bool Parser::Impl::parseCommand()
         return false;
     }
 
-    if (token() == Lexer::Special && tokenValue() == QLatin1Char('(')) {   // test-list
+    if (token() == Lexer::Special && tokenValue() == QLatin1Char('(')) { // test-list
         if (!parseTestList()) {
             assert(error());
             return false;
         }
-    } else if (token() == Lexer::Identifier) {   // should be test:
+    } else if (token() == Lexer::Identifier) { // should be test:
         if (!parseTest()) {
             assert(error());
             return false;
@@ -309,7 +283,7 @@ bool Parser::Impl::parseCommand()
         consumeToken();
     } else if (tokenValue() == QLatin1String("{")) { // block
         if (!parseBlock()) {
-            return false;    // it's an error since we saw '{'
+            return false; // it's an error since we saw '{'
         }
     } else {
         makeError(Error::MissingSemicolonOrBlock);
@@ -507,12 +481,12 @@ bool Parser::Impl::parseTest()
         goto TestEnd;
     }
 
-    if (token() == Lexer::Special && tokenValue() == QLatin1Char('(')) {   // test-list
+    if (token() == Lexer::Special && tokenValue() == QLatin1Char('(')) { // test-list
         if (!parseTestList()) {
             assert(error());
             return false;
         }
-    } else if (token() == Lexer::Identifier) {   // should be test:
+    } else if (token() == Lexer::Identifier) { // should be test:
         if (!parseTest()) {
             assert(error());
             return false;
